
(*
    Zupanijsko natjecanje 2004 / 2. podskupina
    3. zadatak - GUMBI
    Rjesenje napisao Ivan Sikiric (isikiric@hotmail.com)

Opis algoritma:
Pocevsi od pocetnog stanja pretrazivanjem u sirinu nalazimo minimalan
potreban broj poteza (tj. pritisaka) da dodjemo u konacno stanje.

Napomena:
Da bi sve stalo u memoriju, moramo svakom mogucem stanju pridruziti
neki prirodni broj:
ako je n-ti gumb ukljucen, pridruzimo mu broj 2^(n-1), a inace 0
broj stanja dobijemo zbrajanjem brojeva pridruzenih gumbima
primjer:
imamo 5 gumba, ukljuceni su samo gumbi 1, 3 i 4.
gumb 1 -> 2^0 = 1
gumb 2 -> 0
gumb 3 -> 2^2 = 4
gumb 4 -> 2^3 = 8
gumb 5 -> 0
broj pridruzen stanju = 1+4+8 = 13 tj. 01101
*)

program gumbi;

const ISKLJUCEN = 0;
      UKLJUCEN  = 1;
      MAX       = 20;               //  broj gumba
      MAXSTANJA = 1 shl MAX;        //  =2^(broj gumba)=1048576
      MAXQ      = MAXSTANJA;        //  velicina queuea
      INF       = 1000000000;       //  beskonacnost
      RJESENJE  = 4;                //  rjesenje - samo treci gumb:
                                    //  00000000000000000100=4

type stanje = array[0..MAX-1] of longint;

var  staro, novo : stanje;
     g : array[0..MAX-1, 1..MAX] of longint;    //podaci o gumbima
     gnum : array[0..MAX-1] of longint;         //podaci o gumbima
     pot : array[0..MAXSTANJA] of longint;      //broj poteza do
                                                //   traznog stanja
     q : array[0..MAXQ] of longint;             //queue (rep, fifo)
     n, i, j, qp, qk, c : longint;
     nasao : boolean;

//prebacuje polje stanja u 32bitni broj radi ustede memorije
procedure stanje_broj(var s : stanje; var e : longint);
var i : longint;
begin
    e:=0;
    for i:=n-1 downto 0 do e:=e*2+s[i];
end;

//prebacuje broj stanja u polje radi lakse obrade
procedure broj_stanje(var s : stanje; e : longint);
var i : longint;
begin
    for i:=0 to n do
    begin
        s[i]:=e mod 2;
        e := e div 2;
    end;
end;

//stavlja stanje u queue i pamti broj potrebnih poteza
procedure put(var s : stanje; c : longint);
var e : longint;
begin
    stanje_broj(s, e);
    if pot[e]>c then
    begin
        pot[e]:=c;
        q[qp]:=e;
        if qp<MAXQ then qp:=qp+1 else qp:=0;
    end;
end;

//vadi stanje iz queuea i broj potrebnih poteza
procedure pop(var s : stanje; var c : longint);
var e : longint;
begin
    e := q[qk];
    if qk<MAXQ then qk:=qk+1 else qk:=0;
    broj_stanje(s, e);
    c:=pot[e];
end;

begin
    readln(n);
    //ucitavanje pocetnog stanja:
    for i:=0 to n-1 do read(staro[i]);
    //ucitavanje podataka o gumbima:
    for j:=0 to n-1 do
    begin
        readln;
        read(gnum[j]);
        for i:=1 to gnum[j] do
        begin
            read(g[j][i]);
            g[j][i]:=g[j][i]-1;
        end;
    end;

    for i:=0 to MAXSTANJA do pot[i]:=INF;
    qp:=0;
    qk:=0;
    put(staro, 0);
    nasao:=false;
    repeat
        pop(staro, c);
        for i:=0 to n-1 do if staro[i]=ISKLJUCEN then
        begin
            for j:=0 to n-1 do novo[j]:=staro[j];
            for j:=1 to gnum[i] do novo[g[i, j]]:=ISKLJUCEN;
            novo[i]:=UKLJUCEN;
            put(novo, c+1);
            stanje_broj(novo, j);
            if j=RJESENJE then
            begin
                nasao:=true;
                break;
            end;
        end;
    until nasao;
    writeln(pot[RJESENJE]);
end.
