
/*
  Croatia 2005 / Final Exam #2
  Problem POLJA

  Za pocetak postupkom sazimanja pretvorimo pocetni koordinatni sustav u novi,
  sasavljen od 2N*2N "jedinicnih" kvadrata. Primijetimo da je geometrija
  pravokutnika ocuvana, tj. ono sto je bio pravokutnik u pocetnom sustavu ostaje
  pravokutnik u novom. Ovo nam omogucava da radimo sa matricom 2N*2N u kojoj
  svaki jedinicni kvadrat pobojamo bojom pravokutnika kojem on pripada. Takoder
  moramo za svaki kvadratic zapamtiti i njegovu sirinu i visinu u pocetnom
  koordinatnom sustavu.

  Zamislimo da krenemo horizontalnom linijom od vrha matrice i liniju spustamo
  za po jedan kvadratic. U svakoj iteraciji mozemo konstruirati histogram
  kvadratica koji "lezi" na toj liniji. Ako u svakoj iteraciji nademo najveci
  jednobojni pravokutnik u trenutnom histogramu, sigurno smo nasli i ukupno
  najveci pravokutnik, jer on mora lezati na nekoj horizontalnoj liniji.

  Jedan histogram rjesavamo ovako: obradujemo stupce slijeva na desno jedan po
  jedan i odrzavamo stack (stog) mogucih rjesenja: moguce rjesenje je
  pravokutnik odreden lijevom granicom i visinom. Cilj nam je sva moguca
  rjesenja prosirivati nadesno dok je to moguce. Kad dode novi stupac
  ("trenutni"), postupamo po sljedecem:
  - ako stack nije prazan, a boja novog stupca nije jednaka onoj na stacku,
    ispraznimo stack jer rjesenja sa stacka ne mozemo vise prosiriti nadesno
    (ona sigurno zavrsavaju stupcem koji smo dodali prije trenutnog)
  - ako stack nije prazan i boja trenutnog stupca odgovara, skidamo moguca
    rjesenja sa stacka dok je trenutni stupac nizi od njih. Ocito je da se
    pravokutnik prekida ako pokusamo dodati stupac koji je nizi od pravokutnika.
  - otvaramo novo moguce rjesenje

  Vremenska slozenost sazimanja je theta(n^2) u najgorem slucaju. Nakon toga
  radimo n iteracija, a u svakoj iteraciji rjesavamo jedan histogram u
  slozenosti theta(n). Tako je ukupna vremenska slozenost algoritma u najgorem
  (a i prosjecnom) slucaju theta(n^2), kao i memorijska.
*/

#include <algorithm>
#include <cstdio>
#include <stack>
#include <map>
#include <vector>

#define MAXN 2500

using namespace std;

typedef long long llint;

int n;
int x1[MAXN], y1[MAXN], x2[MAXN], y2[MAXN], col[MAXN];
vector<int> x, y;
map<int,int> xi, yi;
char c[2*MAXN][2*MAXN];

int cc[2*MAXN];
int h[2*MAXN];

int main( void ) {
   // ucitavanje i sazimanje

   scanf( "%d", &n );
   for( int i = 0; i < n; ++i ) {
      scanf( "%d%d%d%d%d", &x1[i], &y1[i], &x2[i], &y2[i], &col[i] );
      if( x1[i] > x2[i] ) swap( x1[i], x2[i] );
      if( y1[i] > y2[i] ) swap( y1[i], y2[i] );
      x.push_back( x1[i] ); y.push_back( y1[i] );
      x.push_back( x2[i] ); y.push_back( y2[i] );
   }
   sort( x.begin(), x.end() ); x.erase( unique( x.begin(), x.end() ), x.end() );
   sort( y.begin(), y.end() ); y.erase( unique( y.begin(), y.end() ), y.end() );

   for( int i = 0; i < (int)x.size(); ++i ) xi[x[i]] = i;
   for( int i = 0; i < (int)y.size(); ++i ) yi[y[i]] = i;

   for( int i = 0; i < n; ++i )
      for( int xx = xi[x1[i]]; xx < xi[x2[i]]; ++xx )
         for( int yy = yi[y1[i]]; yy < yi[y2[i]]; ++yy )
            c[yy][xx] = col[i];

   // rjesavanje

   llint rj = 0;

   for( int i = y.size()-1; i>=0; --i ) {
      for( int j = 0; j < (int)x.size(); ++j )
         if( c[i][j] == cc[j] ) h[j] += y[i+1]-y[i];
         else { cc[j] = c[i][j]; h[j] = y[i+1]-y[i]; }

      int zadnjaboja = -1;
      stack< pair<llint,llint> > S;
      for( int j = 0; j < (int)x.size(); ++j ) {
         if( cc[j] != zadnjaboja )
            for( ;!S.empty(); S.pop() )
               rj = max( rj, (x[j]-S.top().first)*S.top().second );

         zadnjaboja = cc[j];
         if( cc[j] == 0 ) continue;

         pair<llint, llint> t( x[j], h[j] );
         for( ; !S.empty() && S.top().second >= h[j]; S.pop() ) {
            t.first = S.top().first;
            rj >?= (x[j]-S.top().first)*S.top().second;
         }
         S.push( t );
      }
   }

   printf( "%lld\n", rj );

   return 0;
}
