
/*
  Croatia 2005 / Regional Competition / Juniors
  Problem OVCE

  Opis algoritma:
  Za svako polje koje dosad nismo posjetili pretpostavimo da je dio
  nekog ogradjenog prostora i napravimo flood-fill.
  Flood-fill nalazi broj ovaca i vukova u jednom ogradjenom prostoru
  pa znamo koje zivotinje prezive i tim vrijednostima azuriramo
  varijable koje na kraju sadrze ukupni broj ovaca i broj vukova.
  U ovom rjesenju flood-fill je implementiran pomocu DFS-a
  (depth-first search), iako smo mogli koristiti i BFS.

  Vremenska slozenost: O(R*S)
*/

#include <stdio.h>

#define MAX_STRANICA 250
#define OGRADA '#'
#define PRAZNO '.'
#define OVCA 'o'
#define VUK 'v'
#define RUB 'r'
#define BIO 'b'

int broj_redaka,broj_stupaca;
char dvoriste[MAX_STRANICA + 2][MAX_STRANICA + 2];
int ogradjeni_prostor;

int broj_ovaca,broj_vukova;
int ukupno_ovaca,ukupno_vukova;

void ucitaj(void)
{
  int i,j;
  char znak;

  scanf("%d%d",&broj_redaka,&broj_stupaca);
  for (i = 0;i <= broj_redaka + 1;++i)
    dvoriste[i][0] = dvoriste[i][broj_stupaca + 1] = RUB;
  for (i = 0;i <= broj_stupaca + 1;++i)
    dvoriste[0][i] = dvoriste[broj_redaka + 1][i] = RUB;

  scanf("%c",&znak);
  for (i = 1;i <= broj_redaka;++i)
  {
    for (j = 1;j <= broj_stupaca;++j)
      scanf("%c",&dvoriste[i][j]);
    scanf("%c",&znak);
  }
}

void prosiri_se(int a,int b)
{
  if (dvoriste[a][b] == RUB)
  {
    ogradjeni_prostor = 0;
    return;
  }

  if (dvoriste[a][b] == OGRADA || dvoriste[a][b] == BIO)
    return;

  if (dvoriste[a][b] == OVCA)
    ++broj_ovaca;
  if (dvoriste[a][b] == VUK)
    ++broj_vukova;

  dvoriste[a][b] = BIO;

  prosiri_se(a - 1,b);
  prosiri_se(a,b + 1);
  prosiri_se(a + 1,b);
  prosiri_se(a,b - 1);
}

void rijesi(void)
{
  int i,j;

  ukupno_ovaca = ukupno_vukova = 0;

  for (i = 1;i <= broj_redaka;++i)
    for (j = 1;j <= broj_stupaca;++j)
    {
      if (dvoriste[i][j] == OGRADA || dvoriste[i][j] == BIO)
        continue;

      broj_ovaca = broj_vukova = 0;
      ogradjeni_prostor = 1;

      prosiri_se(i,j);

      if (ogradjeni_prostor)
      {
        if (broj_ovaca > broj_vukova)
          ukupno_ovaca += broj_ovaca;
        else
          ukupno_vukova += broj_vukova;
      }
    }
}

int main(void)
{
  ucitaj();
  rijesi();
  printf("%d %d\n",ukupno_ovaca,ukupno_vukova);

  return 0;
}
