
/*
  Hrvatska informaticka olimpijada 2006
  Zadatak BANANA

  Za neki broj X mozemo efikasno odrediti da li je moguce postici maksimalnu
  udaljenost D sa K kuna tako da D manji ili jednak od X.

  Binarnim pretrazivanjem po X dolazimo do rjesenja.

  Rekurzijom za svaki vrh racunamo udaljenost do njemu najudaljenijeg vrha koji
  nije blize pocetnom vrhu. Pomocu tih udaljenosti rekurzijom provjeravamo koje
  udaljenosti od pocetnog vrha je moguce postici popravljanjem cesta.

  Vazno je uociti: ako je potrebno popraviti neku cestu na putu od pocetnog
  vrha do vrha sa prevelikom udaljenoscu, onda popravak treba obaviti sto blize
  pocetnom vrhu, jer time smanjujemo udaljenosti od pocetnog vrha do svih vrhova
  nakon te ceste. Popravljanje neke druge, udaljenije ceste nikako ne moze
  dovesti do boljeg rjesenja.
*/

#include <algorithm>
#include <cstdio>
#include <vector>

using namespace std;

#define MAX 100000

int N, R;

struct edge {
   int X, Y, A, B;
};
bool operator < ( const edge &e1, const edge &e2 ) { return e1.X < e2.X; }

vector<edge> E;
int V[MAX+1];

int maxi[MAX];
int mini[MAX];

void dfs( int i, int dad ) {
   maxi[i] = 0;
   mini[i] = 0;
   for( int e = V[i]; e < V[i+1]; ++e ) {
      int j = E[e].Y;
      if( j == dad ) continue;
      dfs( j, i );

      maxi[i] >?= E[e].A + maxi[j];
      mini[i] >?= E[e].B + mini[j];
   }
}

int cost( int i, int dad, int dubina ) {
   int ret = 0;

   for( int e = V[i]; e < V[i+1]; ++e ) {
      int j = E[e].Y;
      if( j == dad ) continue;

      int x = dubina - maxi[j];
      x <?= E[e].A;
      x >?= E[e].B;
      ret += E[e].A-x + cost( j, i, dubina - x );
   }
   return ret;
}

int main( void ) {
   scanf( "%d%d", &N, &R );
   for( int i = 1; i < N; ++i ) {
      edge e;
      scanf( "%d%d%d%d", &e.X, &e.Y, &e.A, &e.B ); --e.X; --e.Y;
      E.push_back( e );
      swap( e.X, e.Y );
      E.push_back( e );
   }

   sort( E.begin(), E.end() );
   V[0] = 0;
   for( int i = 1; i < N; ++i )
      for( V[i] = V[i-1]; V[i] < E.size() && E[V[i]].X < i; ++V[i] );
   V[N] = E.size();

   dfs( 0, -1 );

   int lo = mini[0], hi = maxi[0];
   while( lo < hi ) {
      int mid = (lo+hi)/2;
      if( cost( 0, -1, mid ) <= R ) hi = mid; else lo = mid+1;
   }
   printf( "%d\n", lo );

   return 0;
}
