
/*
  Hrvatska informaticka olimpijada 2006
  Zadatak TROKUT

  Neka je zadan trokut ABC, oznacimo sa 1 poluravninu
  odredjenu pravcem BC koja ne sadrzi tocku A, analogno
  oznacimo i poluravnine 2 i 3. Neka su 12, 13 i 23 presjeci
  odgovarajucih poluravnina. Ako k[X] oznacava broj tocaka u
  podrucju X onda se broj tocaka unutar trokuta ABC moze
  izraziti kao k[ABC] = N - (k[1] + k[2] + k[3] - k[12] -
  k[23] - k[13]).

      \12|
       \ |
        \|
         C
         |\    1
     2   | \
         |  \
         |   \
      ---A----B---
         |     \
      23 |      \ 13
         |  3    \

  Oznacimo l[ABC] = N - (k[1] + k[2] + k[3]). Ako su podrucja
  12, 23, i 31 prazna onda je l[ABC] = k[ABC]. Sa druge
  strane, ako ta podrucja nisu prazna onda je l[ABC] <
  k[ABC].

  Kljucna dosjetka je sljedeca: ako je trokut ABC doista
  rjesenje onda podrucja 12, 23 i 13 moraju biti prazna.
  Naime kada bi, na primjer, podrucje 12 sadrzavalo tocku D,
  tada bi trokut ABD sadrzavao trokut ABC pa samim time i
  strogo vise tocaka nego trokut ABC.

  Stoga ako nadjemo trokut takav da je l[ABC] najvece moguce,
  onda smo nasli rjesenje.

  l[ABC] za sve trokute racunamo u dva koraka. U prvom
  koraku za svaka dva vrha A i B izracunamo k[AB], broj
  tocaka koje leze 'desno' od usmjerog pravca A, B. U drugom
  koraku, za svaki pozitivno orijentirani trokut ABC
  izracunamo l[ABC] kao N - (k[AB] + k[BC] + k[CA]).

  Slozenost oba dva koraka pa tako i cijelog rjesenja je
  O(n^3) uz potrosnju O(n^2) memorije.
*/

#include <cstdio>
#include <cstring>

typedef long long llint;

const int MAXN = 300;

int n;
int x[MAXN], y[MAXN];

int b[MAXN][MAXN];

int naj;
int naja, najb, najc;

int ccw( int a, int b, int c ) {
   llint tmp = (llint)(x[b]-x[a])*(y[c]-y[a]) - (llint)(x[c]-x[a])*(y[b]-y[a]);
   if( tmp < 0 ) return -1;
   if( tmp > 0 ) return 1;
   return 0;
}

void rijesi() {
   naj = -1;

   memset( b, 0, sizeof b );

   for( int i = 0; i < n; ++i )
      for( int j = 0; j < n; ++j )
         for( int k = 0; k < n; ++k )
            if( ccw(i, j, k) == -1 )
               b[i][j]++;

   for( int i = 0; i < n; ++i )
      for( int j = 0; j < n; ++j ) if( i != j )
         for( int k = 0; k < n; ++k ) if( k != i && k != j && ccw(i, j, k) == 1 )
            if( n-b[i][j]-b[j][k]-b[k][i] > naj ) {
               naj=n-b[i][j]-b[j][k]-b[k][i];
               naja=i;
               najb=j;
               najc=k;
            }
}

int main( void ) {
   scanf( "%d", &n );
   for( int i = 0; i < n; ++i )
      scanf( "%d%d", &x[i], &y[i] );

   rijesi();

   printf( "%d\n", naj );
   printf( "%d %d %d\n", naja+1, najb+1, najc+1 );

   return 0;
}
