
{
  DMIH 2006 - Drugi dan natjecanja
  Srednjoskolska skupina - I. podskupina
  Zadatak KOCKICE

  Slijedeci tekst pretpostavlja da je citatelj dobro upoznat s metodom
  dinamickog progamiranja.

  Najjednostavnije bismo zadatak mogli rjesiti rekurzijom koja bi za zadanu
  konfiguraciju stupaca probala slijedecu kockicu postaviti u svaki od tri
  stupca, te za svaki od tih slucajeva pozvati rekurziju s novim stanjem stupaca.
  Dakle, to rjesenje ima slozenost O(3^N) sto je naravno presporo za dana
  ogranicenja u ovom zadatku.

  Prva stvar koju mozemo primjetiti je da ne moramo racunati ukupan broj bodova
  na kraju dok pobacamo sve kockice na stupce, vec to mozemo raditi 'u hodu' pri
  nastanku svake grupe (kada kockica padne na kockicu koja sadrzi drugo slovo).

  Sada mozemo nasu rekurziju preurediti tako da za zadanu konfiguraciju stupaca
  vraca najveci broj bodova koji je moguce ostvariti od tog trenutka na dalje.

  Dakle, ako ovako preuredimo rekurziju, mozemo primjetiti da nas zapravo i ne
  zanima cijela konfiguracija stupaca, jer za sve grupe kockica koje su
  'zakopane' ispod grupa kockica na vrhu ne trebamo racunati broj bodova - on je
  vec izracunat prije poziva rekurzije.

  Znaci, sve sto nas zanima u nekom trenutku je:
  1) Koliko smo do sada bacili kockica na stupce, tj. koju slijedecu bacamo
  2) Koje slovo je na vrhu prvog stupca, te koliko ih je
  3) Koje slovo je na vrhu drugog stupca, te koliko ih je
  4) Koje slovo je na vrhu treceg stupca, te koliko ih je

  Dodatno, ako na vrhu ima vise od 5 kockica s istim slovom, mozemo se ponasat
  kao da ih ima tocno 5, jer je broj osvojenih bodova za grupe vece od 5 isti.

  Dakle stanje na stupcima mozemo opisati uredjenom sedmorkom
  (slijedeca,slovo1,koliko1,slovo2,koliko2,slovo3,koliko3)
  sto ukupno cini 1000*26*6*26*6*26*6 = 3796416000 razlicitih stanja sto je
  previse.

  Da bismo dobili sve bodove potrebna je jos slijedeca dosjetka:
  Kako redoslijed stupaca nikako ne utjece na ukupan broj bodove, mozemo ih
  permutirat (mijenjati im mjesta) po volji. To nam dopusta da stupac u koji
  smo bacili zadnju kockicu uvijek stavimo na prvo mjesto.
  Ako to napravimo onda ne moramo dodatno pamtiti koje slovo se nalazi u prvom
  stupcu jer znamo koju kockicu smo zadnju bacili.
  Tako se rjesavamo dimenzije 'slovo1' u opisu stanja sto smanjuje broj stanja
  26 puta, pa dobivamo ukupno 146016000 razlicitih stanja.

  Radi memorijskog ogranicenja rjesenje ne mozemo implementirati rekurzijom, vec
  je potrebno iterativno popunjavati tablicu kojoj smo sazeli prvu dimenziju s N
  na 2.
}

program kockice;

var
   n, i : longint;
   f : array[0..5] of longint;
   slova : array[1..1000] of char;
   dp : array[1..2, 0..5, 1..26, 0..5, 1..26, 0..5] of longint;
   AA, a, BB, b, CC, c, x : longint;
   curr, next : longint;
   t, val, ret : longint;

procedure memset( i : longint );
var
   AA, a, BB, b, CC : longint;
begin
   for AA := 0 to 5 do
      for a := 1 to 26 do
         for BB := 0 to 5 do
            for b := 1 to 26 do
               for CC := 0 to 5 do
                  dp[i, AA, a, BB, b, CC] := -1;
end;

function min( a, b : longint ) : longint;
begin
   if a < b then min := a else min := b;
end;

procedure update( var a : longint; val : longint );
begin
   if val > a then a := val;
end;

begin
   f[0] := 0;
   for i := 1 to 5 do read( f[i] );
   readln;
   readln( n );
   readln( slova );

   curr := 1;
   next := 2;

   memset( curr );
   dp[1][0][1][0][1][0] := 0;

   c := ord( 'A' ) - 64;

   for i := 1 to n do begin
      memset( next );

      x := ord( slova[i] ) - 64;

      for AA := 0 to 5 do begin
         for a := 1 to 26 do begin
            for BB := 0 to 5 do begin
               for b := 1 to 26 do begin
                  for CC := 0 to 5 do begin
                     { (i,AA,a,BB,b,CC) predstavlja stanje }

                     val := dp[curr, AA, a, BB, b, CC];
                     if val = -1 then continue;

                     { stavljamo u prvi stupac }
                     t := min( AA+1, 5 );
                     if x = a then update( dp[next, CC, c, BB, b, t], val )
                     else          update( dp[next, CC, c, BB, b, 1], val + f[AA] );

                     { stavljamo u drugi stupac }
                     t := min( BB+1, 5 );
                     if x = b then update( dp[next, AA, a, CC, c, t], val )
                     else          update( dp[next, AA, a, CC, c, 1], val + f[BB] );

                     { stavljamo u treci stupac }
                     t := min( CC+1, 5 );
                     if x = c then update( dp[next, AA, a, BB, b, t], val )
                     else          update( dp[next, AA, a, BB, b, 1], val + f[CC] );
                  end;
               end;
            end;
         end;
      end;

      curr := 3-curr;
      next := 3-next;
      c := x;
   end;

   ret := 0;
   for AA := 0 to 5 do begin
      for a := 1 to 26 do begin
         for BB := 0 to 5 do begin
            for b := 1 to 26 do begin
               for CC := 0 to 5 do begin
                  val := dp[curr, AA, a, BB, b, CC];
                  if val = -1 then continue;

                  update( ret, val + f[AA] + f[BB] + f[CC] );
               end;
            end;
         end;
      end;
   end;

   writeln( ret );
end.
