
/*
  DMIH 2006 - Prvi dan natjecanja
  Srednjoskolska skupina - II. podskupina
  Zadatak MARATON

  Ako zamislimo rjesenje koje simulira nogometni maraton utakmicu po utakmicu
  primjetiti cemo da su jedini podatci koji nas u nekom trenutku zanimaju:
  A) redni broj tima koji je upravo usao na teren
  B) redni broj tima koji je od prije na terenu (kao pobjednik)

  Vidimo da ta dva podatka (nazovimo ih stanjem) jedinstveno odredjuju pobjednika
  te utakmice kao i redni broj tima koji treba uci na teren umjesto porazog tima,
  tj. stanje koje slijedi nakon trenutnoga.

  Kako je ukupni broj razlicitih stanja ogranicen, to znaci da ce maraton uci u
  ciklus - odredjen slijed utakmica ce se poceti ponavljati i ponavljati ce se
  do kraja turnira.

  Buduci da su dva podatka u stanju ograniceni brojem N, stanja ce se definitivno
  poceti ponavljati nakon N*N utakmica.

  Gornje zakljucke mozemo iskoristiti kako bismo ubrzali nas program tako da
  nakon detekcije ciklusa ubrojimo ishode iz utakmica unutar ciklusa odgovarajuci
  broj puta i na taj nacin smanjimo broj X.
*/

#include <cstdio>
#include <vector>

using namespace std;

#define MAXN 1000

typedef long long llint;

int N;
char tablica[MAXN][MAXN+1];
int P1; // tim koji je od prije na terenu
int P2; // tim koji je zadnji dosao na teren

int brojac; // broj odigranih utakmica
int zadnja[MAXN][MAXN]; // kada su timovi zadnji puta igrali

void operator += ( vector<llint> &A, const vector<llint> &B ) {
   for( int i = 0; i < N; ++i ) A[i] += B[i];
}

vector<llint> operator * ( const vector<llint> &A, llint B ) {
   vector<llint> C( A );
   for( int i = 0; i < N; ++i ) C[i] *= B;
   return C;
}

int slijedeci( int x ) {
   if( ++x == N ) return 0;
   return x;
}

vector<llint> simuliraj( int broj_utakmica ) {
   vector<llint> ret( N, 0 );

   int P3;
   while( broj_utakmica-- ) {
      zadnja[P1][P2] = brojac++;

      // nadji tim P3 koji igra slijedecu utakmicu
      for( P3 = slijedeci(P2); P3==P1 || P3==P2; P3 = slijedeci(P3) );

      if( tablica[P1][P2] == '0' ) P1 = P2; // P2 je pobjedio P1, pa ostaje na terenu

      P2 = P3; // novi tim je P3

      ++ret[P1];
      ++ret[P2];
   }

   return ret;
}

int main( void ) {
   llint X;
   scanf( "%d%lld", &N, &X );
   for( int i = 0; i < N; ++i ) scanf( "%s", tablica[i] );

   vector<llint> ret( N, 0 );

   if( X > 0 ) { // prvu utakmicu igraju timovi 0 i 1
      ++ret[P1=0];
      ++ret[P2=1];
      --X;
   }

   if( X > N*N ) { // sigurno postoji ciklus
      // udji u ciklus
      ret += simuliraj( N*N );
      X -= N*N;

      // izracunaj duljinu ciklusa i zbroji ga 'broj' puta
      llint ciklus = brojac - zadnja[P1][P2];
      llint broj = X/ciklus;
      ret += simuliraj( ciklus ) * broj;
      X -= broj * ciklus;
   }

   ret += simuliraj( X ); // zbroji ono sto je ostalo

   for( int i = 0; i < N; ++i ) {
      if( i ) printf( " " );
      printf( "%lld", ret[i] );
   }
   printf( "\n" );

   return 0;
}
