
/*
  DMIH 2006 - Drugi dan natjecanja
  Srednjoskolska skupina - II. podskupina
  Zadatak GRADILISTE

  Za kran kazemo da je dostupan ako je moguce prenijet teret od ulaza gradilista
  do bilo koje tocke unutar njegovog dohvata.

  Za dva krana kazemo da su povezani ako se kruznice koje opisuju njihove
  dohvate sjeku u barem jednoj tocki. Izracunavanje dostupnosti kranova svodi
  se na pronalazak povezanih komponenti unutar grafa u kojem kranovi
  predstavljaju cvorove, a njihova povezanost bridove.

  Dakle, svi kranovi koji su u istoj povezanoj komponenti kao i neki kran koji
  dohvaca ulaz gradilista su dostupni.

  Nakon sto pronadjemo sve dostupne kranove jedino sto nam preostaje je za svako
  odrediste provjeriti je li ono unutar dohvata bilo kojeg dostupnog krana.
*/

#include <cmath>
#include <cstdio>

#define MAX 100
#define EPS 1e-10

int n;

struct tocka { double x, y; };
struct kruznica { tocka S; double R; };

kruznica kran[MAX];
int dostupan[MAX];

double udalj( tocka A, tocka B ) {
   return sqrt( (A.x-B.x)*(A.x-B.x) + (A.y-B.y)*(A.y-B.y) );
}

void dfs( int i ) {
   if( dostupan[i] ) return;
   dostupan[i] = 1;

   for( int j = 0; j < n; ++j )
      if( udalj( kran[i].S, kran[j].S ) <= kran[i].R + kran[j].R )
         dfs( j );
}

int main( void ) {
   double X, Y;
   scanf( "%lf%lf", &X, &Y );
   tocka ulaz;
   ulaz.x = X/2; ulaz.y = 0;

   scanf( "%d", &n );
   for( int i = 0; i < n; ++i )
      scanf( "%lf%lf%lf", &kran[i].S.x, &kran[i].S.y, &kran[i].R );

   for( int i = 0; i < n; ++i )
      if( udalj( kran[i].S, ulaz ) <= kran[i].R )
         dfs( i );

   int m;
   scanf( "%d", &m );
   for( int i = 0; i < m; ++i ) {
      tocka odrediste;
      scanf( "%lf%lf", &odrediste.x, &odrediste.y );

      int ok = 0;
      for( int j = 0; j < n; ++j )
         if( dostupan[j] )
            if( udalj( kran[j].S, odrediste ) <= kran[j].R )
               ok = 1;

      if( ok ) printf( "DA\n" );
      else printf( "NE\n" );
   }

   return 0;
}
