
/*
  DMIH 2006 - Drugi dan natjecanja
  Srednjoskolska skupina - II. podskupina
  Zadatak KUTIJE

  Tvrdnje iz zadatka koje govore kada su kuglice slozene nam zapravo kazu da
  kuglice moraju biti rasporedjene tako da su na pocetku sve crne, a na kraju
  bijele kuglice ili na pocetku sve bijele, a na kraju crne kuglice.

  Rijesit cemo oba slucaja i ispisati ono rjesenje koje se sastoji od manje
  koraka.

  Pretpostavimo bez gubitka opcenitosti da rjesavamo problem gdje zelimo bijele
  kuglice na pocetku, a crne na kraju.

  Taj problem mozemo rijesiti slijedecim 'pohlepnim' algoritmom.

  Ponavljamo ova 4 koraka sve dok kuglice nisu slozene:
  1. Idemo slijeva nadesno i uzmimamo prve dvije crne kuglice na koje naletimo
  2. Pomicemo se na najdesniju kutiju koja sadrzi bijelu kuglicu
  3. Idemo sdesna nalijevo i mijenjamo crne kuglice za prve bijele na koje naletimo
  4. I dalje idemo nalijevo i ubacujemo bijele kuglice u praznine.

  Gornji algoritam je ocito valjan (rjesava zadani problem), ali i optimalan sto
  je manje ocito. Dokaz optimalnosti je prekompliciran da bi se ovdje iznjeo i
  nije potreban za rjesavanje zadatka.

  Dovoljno se upitati: "ionako jednom moramo otici po najudaljenije kuglice koje
  nisu na pravim mjestima, pa zasto ne odmah?"
*/

#include <algorithm>
#include <cstdio>
#include <string>
#include <vector>

using namespace std;

typedef pair<int,int> par;
#define B first
#define C second

int n;

string bijelu = "BIJELU";
string crnu = "CRNU";

// stavlja bijele na pocetak, a crne na kraj. int granica je broj bijelih kutija
vector<string> solve( vector<par> kutije, int granica ) {
   vector<string> ret;

   par dizalica;
   int i = 0, left = 0, right = n-1;

   // jedna faza se sastoji od cetiri koraka
   for( ;; ) {
      // trazimo najlijeviju kutiju s crnom i najdesniju s bijelom unutra
      while( left < granica && kutije[left].C == 0 ) ++left;
      while( right >= granica && kutije[right].B == 0 ) --right;

      if( left >= granica ) break; // znaci da smo gotovi

      // 1. idemo slijeva nadesno do granice... i uzimamo crne
      while( i < granica ) {
         while( kutije[i].C > 0 && dizalica.C < 2 ) {
            kutije[i].C--;
            dizalica.C++;
            ret.push_back( "UZMI " + crnu );
         }
         ret.push_back( "DESNO" );
         ++i;
      }

      // 2. idemo od granice do najdesnije kutije koja ima bijelu
      while( i < right ) {
         ret.push_back( "DESNO" );
         ++i;
      }

      // 3. idemo sdesna nalijevo do granice... i mjenjamo crne za bijele
      while( i >= granica ) {
         while( kutije[i].B > 0 && dizalica.C > 0 ) {
            kutije[i].C++;
            dizalica.C--;
            ret.push_back( "SPUSTI " + crnu );

            kutije[i].B--;
            dizalica.B++;
            ret.push_back( "UZMI " + bijelu );
         }
         ret.push_back( "LIJEVO" );
         --i;
      }

      // 4. idemo od granice prema lijevo i punimo rupe bijelima
      while( i >= left ) {
         while( kutije[i].B+kutije[i].C < 2 ) {
            kutije[i].B++;
            dizalica.B--;
            ret.push_back( "SPUSTI " + bijelu );
         }
         if( i == left ) break;
         ret.push_back( "LIJEVO" );
         --i;
      }
   }

   return ret;
}

void output( vector<string> &rjesenje ) {
   for( int i = 0; i < rjesenje.size(); ++i )
      printf( "%s\n", rjesenje[i].c_str() );
}

int main( void ) {
   vector<par> kutije;
   char buff[10];

   scanf( "%d", &n );

   int cntB = 0, cntC = 0;
   for( int i = 0; i < n; ++i ) {
      scanf( "%s", buff );

      par p;
      if( buff[0] == 'B' ) p.B++; else p.C++;
      if( buff[1] == 'B' ) p.B++; else p.C++;
      kutije.push_back( p );

      cntB += p.B;
      cntC += p.C;
   }

   // probaj s bijelima na pocetku
   vector<string> rjesenje1 = solve( kutije, cntB/2 );

   // pobojaj crne u bijele, a bijele u crne
   for( int i = 0; i < n; ++i ) swap( kutije[i].B, kutije[i].C );
   swap( bijelu, crnu );

   // probaj s crnima na pocetku
   vector<string> rjesenje2 = solve( kutije, cntC/2 );

   // ispisi krace rjesenje
   if( rjesenje1.size() < rjesenje2.size() )
      output( rjesenje1 );
   else
      output( rjesenje2 );

   return 0;
}
