
/*
  Zupanijsko natjecanje 2006 - Srednjoskolska skupina - I. podskupina
  Zadatak TOPLISTA
  Rjesenje napisali: Ante Derek, Luka Kalinovcic, Lovro Puzar

  Opis algoritma:

  Cilj nam je u zadatku izvuci sto vise informacija iz ulaza. Jedna
  stvar koju mozemo primijetiti je da, ako se neki pojam pojavljuje u
  izjavi oblika "od B", tada se on implicitno nalazi i u prvih B+1,
  B+2 itd.

  Na osnovu toga prepoznajemo da se pojam sigurno nalazi na mjestu X
  samo ako su nam poznati svi pojmovi koji se nalaze u prvih X-1
  mjesta (ali ne nuzno i njihov redoslijed).

  Ovu tvrdnju je lako provjeriti: ako znamo da se neki pojam nalazi
  medu prvih X, a znamo tocno X-1 pojmova koji su sigurno ispred
  njega, tada se on mora nalaziti na poziciji X.

  Suprotno, ako nam nije poznato tocno X-1 pojmova koji su sigurno
  ispred nekog pojma, tada se taj pojam moze naci na barem dva mjesta
  (s obzirom na ulaz) pa ne mozemo biti sigurni u njegovu poziciju.

  Slozenosti donje implementacije dominira ucitavanje, za koje je
  potrebno O(N*R) operacija sa stringovima, gdje je N broj izjava, a R
  broj razlicith pojmova koji se pojavljuje u izjavama. Ucitavanje bi
  se moglo ubrzati koristenjem naprednijih struktura podataka (vidi
  C++ rjesenje).

  Slijedi sortiranje u slozenosti O(N log N), a odredivanje pozicija
  traje O(N).
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#define MAXN   1000
#define MAXLEN 30

int  n = 0;
char imena[MAXN][MAXLEN+1];
int  najprije[MAXN];

int nadi( char imena[][MAXLEN+1], int n, const char *s )
{
   int i;
   for ( i=0; i<n; ++i )
      if ( strcmp( imena[i], s ) == 0 )
         return i;
   return -1;
}

int pojamcmp( const void *p1, const void *p2 )
{
   int i1 = *(const int *)p1;
   int i2 = *(const int *)p2;
   if ( najprije[i1] < najprije[i2] ) return -1;
   if ( najprije[i1] > najprije[i2] ) return 1;
   return 0;
}

int main()
{
   int i, nizjava;
   static int sortirano[MAXN];

   scanf( "%d", &nizjava );

   /* zelimo da najprije[pojam] bude najraniji B takav da se pojam
      pojavljuje u izjavi oblika "A od B" */

   for ( i=0; i<nizjava; ++i ) {
      int a, b, j;
      scanf( "%d od %d", &a, &b );

      for ( j=0; j<a; ++j ) {
         static char pojam[MAXLEN+1];
         int poz;
         scanf( "%s", pojam );
         poz = nadi( imena, n, pojam );
         if ( poz == -1 ) {
            poz = n++;
            strcpy( imena[poz], pojam );
            najprije[poz] = b;
         }
         else
            if ( b < najprije[poz] )
               najprije[poz] = b;
      }
   }

   /* sortiramo pojmove po prvom pojavljivanju */
   for ( i=0; i<n; ++i )
      sortirano[i] = i;
   qsort( sortirano, n, sizeof *sortirano, pojamcmp );

   for ( i=0; i<n; ++i ) {

      /* pojam prije trenutnog mora imati razlicito najprije
         pojavljivanje, inace nije moguce odrediti koji od njih je na
         kojoj poziciji */
      if ( i == 0 || najprije[ sortirano[i] ] != najprije[ sortirano[i-1] ] ) {

         /* ako je ispred trenutnog tocno sortirano[i].first-1 pojmova */
         if ( najprije[ sortirano[i] ]-1 == i ) {

            /* onda se trenutni nalazi tocno na poziciji i+1
               (najprije[ sortirano[i] ]) */
            printf( "%d %s\n", najprije[ sortirano[i] ], imena[ sortirano[i] ] );
         }
      }
   }

   return 0;
}
