
/*
  Zupanijsko natjecanje 2006 - Srednjoskolska skupina - I. podskupina
  Zadatak TOPLISTA
  Rjesenje napisali: Ante Derek, Luka Kalinovcic, Lovro Puzar

  Opis algoritma:

  Cilj nam je u zadatku izvuci sto vise informacija iz ulaza. Jedna
  stvar koju mozemo primijetiti je da, ako se neki pojam pojavljuje u
  izjavi oblika "od B", tada se on implicitno nalazi i u prvih B+1,
  B+2 itd.

  Na osnovu toga prepoznajemo da se pojam sigurno nalazi na mjestu X
  samo ako su nam poznati svi pojmovi koji se nalaze u prvih X-1
  mjesta (ali ne nuzno i njihov redoslijed).

  Ovu tvrdnju je lako provjeriti: ako znamo da se neki pojam nalazi
  medu prvih X, a znamo tocno X-1 pojmova koji su sigurno ispred
  njega, tada se on mora nalaziti na poziciji X.

  Suprotno, ako nam nije poznato tocno X-1 pojmova koji su sigurno
  ispred nekog pojma, tada se taj pojam moze naci na barem dva mjesta
  (s obzirom na ulaz) pa ne mozemo biti sigurni u njegovu poziciju.

  Slozenosti donje implementacije dominira ucitavanje, za koje je
  potrebno O(A log R) operacija sa stringovima, gdje je A ukupan broj
  rijeci u izjavama, a R broj razlicith pojmova koji se pojavljuje u
  izjavama.

  Slijedi sortiranje u slozenosti O(R log R), a odredivanje pozicija
  traje O(R).
*/

#include <algorithm>
#include <cstdio>
#include <map>
#include <string>
#include <utility>
#include <vector>

using namespace std;

int main()
{
   int nizjava;
   scanf( "%d", &nizjava );

   // zelimo da najprije[pojam] bude najraniji B takav da se pojam
   // pojavljuje u izjavi oblika "A od B"

   map<string, int> najprije;
   for ( int i=0; i<nizjava; ++i ) {
      int a, b;
      scanf( "%d od %d", &a, &b );

      for ( int j=0; j<a; ++j ) {
         static char buf[21];
         scanf( "%s", buf );

         string ime( buf );
         map<string, int>::iterator mi = najprije.find( ime );
         if ( mi == najprije.end() )
            najprije[ime] = b;
         else
            mi->second = min( b, mi->second );
      }
   }

   // sortiramo pojmove po prvom pojavljivanju

   vector<pair<int, string> > sortirano;
   for ( map<string, int>::iterator i=najprije.begin(); i!=najprije.end(); ++i )
      sortirano.push_back( make_pair( i->second, i->first ) );
   sort( sortirano.begin(), sortirano.end() );

   for ( int i=0; i<(int)sortirano.size(); ++i ) {

      // pojam prije trenutnog mora imati razlicito najprije
      // pojavljivanje, inace nije moguce odrediti koji od njih je na
      // kojoj poziciji
      if ( i == 0 || sortirano[i].first != sortirano[i-1].first ) {

         // ako je ispred trenutnog tocno sortirano[i].first-1
         // pojmova
         if ( sortirano[i].first-1 == i ) {

            // onda se trenutni nalazi tocno na poziciji i+1
            // (sortirano[i].first)
            printf( "%d %s\n", sortirano[i].first, sortirano[i].second.c_str() );
         }
      }
   }

   return 0;
}
