
/*
  Zupanijsko natjecanje 2006 - Srednjoskolska skupina - II. podskupina
  Zadatak SIBICE
  Rjesenje napisali: Ante Derek, Luka Kalinovcic, Lovro Puzar

  Opis algoritma:

  Zadatak rjesavamo tako da za svaki podskup kvadrata nadjemo ukupan
  broj sibica potreban da bi se izgradili svi ti kvadrati. Takodjer, potrebno
  je provjeriti koliko smo ukupno izgradili kvadrata jer je moguce da
  nehotice dobijemo visak. Na primjer, ako odaberemo i izgradimo 4 mala
  kvadrata od sibica, moguce je da smo izgradili i peti kvadrat od njihovih
  djelova.

  Kako je ukupni broj kvadrata jednak samo 14, rekurzivno pretrazivanje
  svih mogucih podskupova je dovoljno efikasno. Radi jednostavnosti
  implementacije, koristimo bit-polja da pamtimo koji kvadrat koristi koju
  sibicu i koje smo sibice do sad iskoristili. Na primjer, ako kvadrat
  A koristi okomitu sibicu koja pocinje u redku I i stupcu J, onda ce
  (12+3*I+J)-ti bit varijable kvadrat[A] biti 1, a inace 0.

  U inicijalizacijskoj fazi odredjujemo koji kvadrat koristi koje sibice.
  Nakon toga, rekurzivno dodajemo novi kvadrat sve dok ne nadjemo
  skup od k kvadrata koji se mogu sloziti sa 24-n sibica.
*/

#include <stdio.h>
#include <stdlib.h>

int n, k;

/* Bit-polja koja pamte koji kvadrat koristi koju sibicu */
int kvadrat[14];

/* Inicijalizacija */
void init (void)
{
        int i, j, l, m;
        int redni=0;

        /* Jedan kvadrat je odredjen gornjim lijevim kutom (i, j), i duljinom stranice l */
        for (i=0; i<3; i++)
                for (j=0; j<3; j++)
                        for (l=1; i+l<=3 && j+l<=3; l++)
                        {
                                kvadrat[redni]=0;
                                for (m=0; m<l; m++)
                                {
                                        /* Vodoravne sibice */
                                        kvadrat[redni]|=(1 << (3*i+j+m));
                                        kvadrat[redni]|=(1 << (3*(i+l)+j+m));
                                        /* Okomite sibice */
                                        kvadrat[redni]|=(1 << (12+3*j+i+m));
                                        kvadrat[redni]|=(1 << (12+3*(j+l)+i+m));
                                }
                                redni++;
                        }
}

/* Prebroji koliko bitova (sibica) ima u bit-polju s */
int prebroji (int s)
{
        int c=0;

        while (s>0)
        {
                c+=s&1;
                s=s>>1;
        }
        return c;
}

/* Prebroji koliko smo kvadrata nacrtali sa sibicama u s */
int prebroji_kvadrate (int s)
{
        int c=0;
        int i;

        for (i=0; i<14; i++)
                if ((kvadrat[i] & ~s)==0)
                        c++;

        return c;
}

/* Ispisi rjesenje i zavrsi */
void gotovo (int s)
{
        int i, j;
        char o;
        static const char C[4]={'.', '|', '-', '+'};

        for (i=0; i<10; i++)
        {
                for (j=0; j<10; j++)
                {
                        o=C[2*(i%3==0)+(j%3==0)];
                        if (i%3==0 && j%3!=0 && ((s>>(i+j/3))&1)==0) o=C[0];
                        if (j%3==0 && i%3!=0 && ((s>>(12+j+i/3))&1)==0) o=C[0];
                        printf("%c", o);
                }
                printf("\n");
        }
        exit(0);
}

/*
   Rekurzivna funkcija koja trazi sve podskupove kvadrata, sljedeci oznacava
   sljedeci kvadrat koji dodajemo, sibice je bit-polje koje oznacava do sad
   upotrebljene sibice.
*/
void nadji (int sljedeci, int sibice)
{
        int brojsibica=prebroji(sibice);
        int brojkvadrata=prebroji_kvadrate(sibice);

        if (brojsibica==24-n && brojkvadrata==k)
                gotovo(sibice);

        if (brojsibica>24-n) return ;
        if (brojkvadrata>k) return ;
        if (sljedeci==14) return ;

        /* Ne dodajemo kvadrat */
        nadji(sljedeci+1, sibice);

        /* Dodajemo kvadrat */
        nadji(sljedeci+1, sibice | kvadrat[sljedeci]);
}

int main (void)
{
        scanf("%d %d", &n, &k);

        init();
        nadji(0, 0);

        printf("Nema rjesenja!\n");

        return 0;
}
