
(*
  Zupanijsko natjecanje 2006 - Srednjoskolska skupina - II. podskupina
  Zadatak SIBICE
  Rjesenje napisali: Ante Derek, Luka Kalinovcic, Lovro Puzar, Ivan Sikiric

  Opis algoritma:

  Zadatak rjesavamo tako da za svaki podskup kvadrata nadjemo ukupan
  broj sibica potreban da bi se izgradili svi ti kvadrati. Takodjer, potrebno
  je provjeriti koliko smo ukupno izgradili kvadrata jer je moguce da
  nehotice dobijemo visak. Na primjer, ako odaberemo i izgradimo 4 mala
  kvadrata od sibica, moguce je da smo izgradili i peti kvadrat od njihovih
  djelova.

  Kako je ukupni broj kvadrata jednak samo 14, rekurzivno pretrazivanje
  svih mogucih podskupova je dovoljno efikasno. Radi jednostavnosti
  implementacije, koristimo bit-polja da pamtimo koji kvadrat koristi koju
  sibicu i koje smo sibice do sad iskoristili. Na primjer, ako kvadrat
  A koristi okomitu sibicu koja pocinje u redku I i stupcu J, onda ce
  (12+3*I+J)-ti bit varijable kvadrat[A] biti 1, a inace 0.

  U inicijalizacijskoj fazi odredjujemo koji kvadrat koristi koje sibice.
  Nakon toga, rekurzivno dodajemo novi kvadrat sve dok ne nadjemo
  skup od k kvadrata koji se mogu sloziti sa 24-n sibica.
*)

program sibice;

var n, k : longint;
    (* Bit-polja koja pamte koji kvadrat koristi koju sibicu: *)
    kvadrat : array[0..13] of longint;

(* Inicijalizacija *)
procedure init;
var i, j, l, m, redni : longint;
begin
    redni:=0;

    (* Jedan kvadrat je odredjen gornjim lijevim kutom (i, j), i duljinom stranice l *)
    for i:=0 to 2 do
        for j:=0 to 2 do
          begin
            l:=1;
            while (i+l<=3)and(j+l<=3) do
              begin
                kvadrat[redni]:=0;
                for m:=0 to l-1 do
                  begin
                    (* Vodoravne sibice *)
                    kvadrat[redni]:= kvadrat[redni] or (1 shl (3*i+j+m));
                    kvadrat[redni]:= kvadrat[redni] or (1 shl (3*(i+l)+j+m));
                    (* Okomite sibice *)
                    kvadrat[redni]:= kvadrat[redni] or (1 shl (12+3*j+i+m));
                    kvadrat[redni]:= kvadrat[redni] or (1 shl (12+3*(j+l)+i+m));
                  end;
                redni:=redni+1;
                l:=l+1;
              end;
          end;
end;

(* Prebroji koliko bitova (sibica) ima u bit-polju s *)
function prebroji(s : longint) : longint;
var c : longint;
begin
    c:=0;
    while s>0 do
      begin
        c := c + s and 1;
        s := s shr 1;
      end;
    prebroji:=c;
end;

(* Prebroji koliko smo kvadrata nacrtali sa sibicama u s *)
function prebroji_kvadrate(s : longint) : longint;
var i, c : longint;
begin
    c:=0;
    for i:=0 to 13 do
        if kvadrat[i] and not s = 0 then c:=c+1;
    prebroji_kvadrate := c;
end;

(* Ispisi rjesenje i zavrsi *)
procedure gotovo(s : longint);
const C : array[0..3] of char = ('.', '|', '-', '+');
var i, j, p1, p2 : longint;
    o : char;
begin
    for i:=0 to 9 do
      begin
        for j:=0 to 9 do
          begin
            if 2*(i mod 3)=0 then p1:=1 else p1:=0;
            if j mod 3 = 0 then p2:=1 else p2:=0;
            o:=C[2*p1+p2];
            if (i mod 3=0)and(j mod 3<>0)and(((s shr (i+j div 3))and 1)=0)   then o:=C[0];
            if (j mod 3=0)and(i mod 3<>0)and(((s shr (12+j+i div 3))and 1)=0) then o:=C[0];
            write(o);
          end;
        writeln;
      end;
    halt(0);
end;

(*
   Rekurzivna funkcija koja trazi sve podskupove kvadrata, sljedeci oznacava
   sljedeci kvadrat koji dodajemo, sibice je bit-polje koje oznacava do sad
   upotrebljene sibice.
*)
procedure nadji(sljedeci, sibice : longint);
var brojsibica, brojkvadrata  : longint;
begin
        brojsibica:=prebroji(sibice);
        brojkvadrata:=prebroji_kvadrate(sibice);

        if (brojsibica=24-n)and(brojkvadrata=k) then gotovo(sibice);

        if brojsibica>24-n then exit;
        if brojkvadrata>k then exit;
        if sljedeci=14 then exit;

        (* Ne dodajemo kvadrat *)
        nadji(sljedeci+1, sibice);

        (* Dodajemo kvadrat *)
        nadji(sljedeci+1, sibice or kvadrat[sljedeci]);
end;

begin
    readln(n, k);
    init;
    nadji(0, 0);
    writeln('Nema rjesenja!');
end.
