(*
  Drzavno natjecanje 2007, srednjoskolska skupina - 2. podskupina
  1. dan natjecanja
  Zadatak OGRADA

  Kako Pascal ne dolazi sa binarnim stablom pretrazivanja,
  implementacija je nuzno kompliciranija nego u jeziku C++. Kao
  zamjenu za binarno stablo koristio sam order-statistic stablo (u nas
  popularno 'tournament tree'), prilagodeno da cuva visine preostalih
  Slavkovih dasaka, efikasno nalazi najvisu dasku ne visu od neke
  granice, te je uklanja iz stabla. Rekonstrukcija je takoder
  problematicna. Ali je cijelo rjesenje efikasnije od svojeg C++
  kompanjona :)
*)

program ograda;

const
   MAXN = 100000;
   MAXV = 10000;

var
   i, n           : longint;
   slavkove, poms : array[1..MAXN] of record visina, indeks : longint; end;
   leine, poml    : array[1..MAXN] of record visina, vrijednost, indeks : longint; end;
   rez, koja      : longint;
   kamo, ispis    : array[1..MAXN] of longint;
   count          : array[1..MAXV] of longint;

procedure sort;
(* Prvo sortira Leine daske silazno po vrijednosti, a zatim Slavkove
   uzlazno po visini (potrebno za rekonstrukciju). Koristi counting
   sort pa je slozenost O(N+MAXV). *)
var
   i : longint;
begin
   for i:=1 to MAXV do count[i] := 0;
   for i:=1 to n do count[leine[i].vrijednost] := count[leine[i].vrijednost]+1;
   for i:=2 to MAXV do count[i] := count[i-1] + count[i];
   
   for i:=n downto 1 do begin
      poml[count[leine[i].vrijednost]] := leine[i];
      count[leine[i].vrijednost] := count[leine[i].vrijednost] - 1;
   end;
   
   for i:=1 to n do leine[n-i+1] := poml[i];

   for i:=1 to MAXV do count[i] := 0;
   for i:=1 to n do count[slavkove[i].visina] := count[slavkove[i].visina]+1;
   for i:=2 to MAXV do count[i] := count[i-1] + count[i];
   
   for i:=n downto 1 do begin
      poms[count[slavkove[i].visina]] := slavkove[i];
      count[slavkove[i].visina] := count[slavkove[i].visina] - 1;
   end;
   
   for i:=1 to n do slavkove[i] := poms[i];
end;

var
   koliko              : array[1..MAXV] of longint;
   drvo, lijevo, desno : array[1..2*MAXV] of longint;

procedure stvori_drvo;
var drvo_brojac : longint;

   function rek_stvori(a, b : longint):longint;
   var node : longint;
   begin
      node := drvo_brojac;
      drvo_brojac := drvo_brojac + 1;

      if a = b then
         drvo[node] := koliko[a]
      else begin
         lijevo[node] := rek_stvori( a, (a+b) div 2 );
         desno[node] := rek_stvori( (a+b) div 2 + 1, b );
         drvo[node] := drvo[ lijevo[node] ] + drvo[ desno[node] ];
      end;
      rek_stvori := node;
   end;

var i : longint;

begin
   for i:=1 to MAXV do koliko[i] := 0;
   for i:=1 to n do koliko[slavkove[i].visina] := koliko[slavkove[i].visina] + 1;
   
   drvo_brojac := 1;
   rek_stvori(1, MAXV);
end;

function trazi(    visina : longint;
               var koja   : longint):boolean;
   function rek_trazi(    node, a, b, qa, qb : longint;
                      var koja               : longint):boolean;
   var
      mid : longint;
      rez : boolean;
   begin
      if drvo[node] = 0 then
         rez := false
      else if a = b then begin
         koja := a;
         rez := true;
      end else begin
         mid := (a+b) div 2;
         if (qb > mid) and rek_trazi(desno[node], mid+1, b, qa, qb, koja) then
            rez := true
         else if (qa <= mid) and rek_trazi(lijevo[node], a, mid, qa, qb, koja) then
            rez := true
         else
            rez := false;
      end;

      if rez then
         drvo[node] := drvo[node] - 1;
      rek_trazi := rez;
   end;

begin
   trazi := rek_trazi(1, 1, MAXV, 1, visina, koja);
end;

procedure rekonstruiraj;
(* Ulaz - niz 'kamo', koji kaze, za svaku Leinu dasku, koja je visina
   Slavkove daske ispred koje ide ta Leina *)
var
   i, lo, hi, mid : longint;
begin
   for i:=1 to n do begin
      (* Binarnim pretrazivanjem nadi prvu dasku koja ima visinu
         kamo[i], a da jos nije iskoristena (indeks > 0) *)
      
      lo := 1; hi := n;
      while lo < hi do begin
         mid := (lo+hi) div 2;
         if (slavkove[mid].visina > kamo[i]) or
            ((slavkove[mid].visina = kamo[i]) and (slavkove[mid].indeks > 0)) then
            hi := mid
         else
            lo := mid+1;
      end;

      ispis[slavkove[lo].indeks] := i;
      slavkove[lo].indeks := 0;
   end;
end;

begin
   readln(n);
   for i:=1 to n do begin
      read(slavkove[i].visina);
      slavkove[i].indeks := i;
   end;
   for i:=1 to n do begin
      read(leine[i].visina, leine[i].vrijednost);
      leine[i].indeks := i;
   end;

   sort;
   stvori_drvo;

   rez := 0;
   for i:=1 to n do begin
      if trazi(leine[i].visina, koja) then
         (* Nasao sam medu Slavkovim dasku visine <= leine[i], nju
            prekrivam Leinom *)
         rez := rez + leine[i].vrijednost
      else
         (* Ne mogu zaraditi na ovoj Leinoj daski pa je stavljam
            ispred najvise Slavkove *)
         trazi(MAXV, koja);
      kamo[leine[i].indeks] := koja;
   end;
   writeln(rez);

   rekonstruiraj;
   write(ispis[1]);
   for i:=2 to n do
      write(' ', ispis[i]);
   writeln;
end.
