#include <algorithm>
#include <cstdio>
#include <vector>

using namespace std;

#define MAXN 2000

const int oo = 1000000000;

typedef pair<int,int> par;

int n, x;
vector<int> adj[MAXN];

struct dinamika {
   int R, S;
   vector<int> dp;
   vector<par> hw;
   void init( int r, int s ) {
      R = r; S = s;
      dp.resize( R*S );
      hw.resize( R*S );
      fill( dp.begin(), dp.end(), -oo );
   }
   inline int & value( int r, int s ) { return dp[r*S+s]; }
   inline par & how( int r, int s ) { return hw[r*S+s]; }

   void update( int r, int s, int Val, par How ) {
      if( value(r,s) >= Val ) return;
      value(r,s) = Val;
      how(r,s) = How;
   }

   vector<par> reconstruct( int s ) {
      vector<par> ret;
      for( int r = R-1; r != 0; --r ) {
         ret.push_back( how(r,s) );
         s -= how(r,s).first + how(r,s).second;
      }
      reverse( ret.begin(), ret.end() ); 
      return ret;
   }
};

struct node {
   int index;
   int size;
   int target;
   dinamika table;
   vector<int> dp;
   vector<node *> children;

   void solve() {
      int m = children.size();
      
      table.init( m+1, size );
      table.value( 0, 0 ) = x-target;
      
      for( int i = 0; i < m; ++i ) {
         node *c = children[i];
         for( int j = 0; j < size; ++j ) {
            int v = table.value(i,j);
            if( v == -oo ) continue;
            
            for( int k = 0; k < c->size; ++k ) {
               if( c->dp[k] == -oo ) continue;            
               
               table.update( i+1, j+k+1, v+c->dp[k], par(1,k) );
               
               if( c->dp[k] >= 0 ) table.update( i+1, j+k, v, par(0,k) );            
            }
         }
      }
      
      dp = vector<int> ( &table.value(m,0), &table.value(m,size) );
   }
   void reconstruct( int k ) {
      int m = children.size();

      vector<par> how = table.reconstruct( k );
      
      for( int i = 0; i < m; ++i ) { // rekonstruiram djecu koja su neovisna o meni
         node *c = children[i];
         if( how[i].first == 0 ) c->reconstruct( how[i].second );
      }
      
      for( int i = 0; i < m; ++i ) { // rekonstruiram djecu koja ce mi dati novac
         node *c = children[i];
         if( how[i].first == 1 && c->dp[how[i].second] >= 0 ) {
            c->reconstruct( how[i].second );
            printf( "%d %d %d\n", c->index, index, c->dp[how[i].second] );
         }
      }
      
      for( int i = 0; i < m; ++i ) { // rekonstruiram djecu kojoj moram dati novac
         node *c = children[i];
         if( how[i].first == 1 && c->dp[how[i].second] < 0 ) {
            printf( "%d %d %d\n", index, c->index, -c->dp[how[i].second] );
            c->reconstruct( how[i].second );
         }
      }
   }
} a[MAXN];

void build_and_solve( int u, int dad ) {
   a[u].size = 1;
   a[u].index = u+1;
   for( vector<int>::iterator it = adj[u].begin(); it != adj[u].end(); ++it ) {
      if( *it == dad ) continue;

      build_and_solve( *it, u ); 

      a[u].children.push_back( &a[*it] );
      a[u].size += a[*it].size;
   }   
   a[u].solve();
}

int main( void ) {
   scanf( "%d", &n );
   scanf( "%d", &x );
   for( int i = 0; i < n; ++i ) scanf( "%d", &a[i].target );
   for( int i = 1; i < n; ++i ) {
      int a, b;
      scanf( "%d%d", &a, &b ); --a; --b;
      adj[a].push_back( b );
      adj[b].push_back( a );
   }
   
   build_and_solve( 0, -1 );

   int ret = 0;
   while( a[0].dp[ret] < 0 ) ++ret;
   printf( "%d\n", ret );

   a[0].reconstruct( ret );

   return 0;
}
