program podjela;

const
   MAXN = 2000;
   oo   = 1000000000;

type par =
   record
      first, second : longint;
   end;

function make_pair(a, b : longint) : par;
begin make_pair.first := a; make_pair.second := b; end;

type arrayofpar = array of par;

type adj_lista = object
   n    : longint;
   elem : array[0..MAXN] of longint;
   procedure init;
   procedure add(x : longint);
end;

procedure adj_lista.init;
begin n := 0; end;

procedure adj_lista.add(x : longint);
begin elem[n] := x; inc(n); end;

var
   n, x : longint;
   adj  : array[0..MAXN] of adj_lista;

type dinamika = object
   Rmax, Smax : longint;
   dp   : array of longint;
   how  : array of par;

   procedure init(R, S : longint);
   function getvalue(r, s : longint) : longint;
   procedure setvalue(r, s, val : longint);
   function gethow(r, s : longint) : par;
   procedure sethow(r, s : longint; hw : par);
   procedure update(r, s, val : longint; hw : par);
   function reconstruct(s : longint) : arrayofpar;
end;                         

procedure dinamika.init(R, S : longint);
var i : longint;
begin
   Rmax := R; Smax := S;
   setlength(dp, R*S);
   setlength(how, R*S);
   for i:=0 to R*S-1 do dp[i] := -oo;
end;

function dinamika.getvalue(r, s : longint) : longint;
begin getvalue := dp[r*Smax+s]; end;

procedure dinamika.setvalue(r, s, val : longint);
begin dp[r*Smax+s] := val; end;

function dinamika.gethow(r, s : longint) : par;
begin gethow := how[r*Smax+s]; end;

procedure dinamika.sethow(r, s : longint; hw : par);
begin how[r*Smax+s] := hw; end;
   
procedure dinamika.update(r, s, val : longint; hw : par);
begin
   if getvalue(r, s) >= val then exit;
   setvalue(r, s, val);
   sethow(r, s, hw);
end;

function dinamika.reconstruct(s : longint) : arrayofpar;
var
   r   : longint;
   ret : arrayofpar;
begin
   setlength(ret, Rmax-1);
   for r:=Rmax-1 downto 1 do begin
      ret[r-1] := gethow(r, s);
      s := s - (gethow(r, s).first + gethow(r, s).second);
   end;
   reconstruct := ret;
end;

type
   pnode = ^node;
   node  = object
      index, size, target: longint;
      table : dinamika;
      dp:    array of longint;
      children:array of pnode;

      procedure solve;
      procedure reconstruct(k : longint);
   end;                          

procedure node.solve;
var
   m, i, j, k, v : longint;
   c             : pnode;
begin
   m := length(children);
   table.init(m+1, size);
   table.setvalue(0, 0, x-target);

   for i:=0 to m-1 do begin
      c := children[i];
      for j:=0 to size-1 do begin
         v := table.getvalue(i, j);
         if v = -oo then continue;

         for k:=0 to c^.size-1 do begin
            if c^.dp[k] = -oo then continue;

            table.update(i+1, j+k+1, v+c^.dp[k], make_pair(1, k));

            if c^.dp[k] >= 0 then table.update(i+1, j+k, v, make_pair(0, k));
         end;
      end;
   end;

   setlength(dp, size);
   for i:=0 to size-1 do dp[i] := table.getvalue(m, i);
end;

procedure node.reconstruct(k : longint);
var
   m, i : longint;
   how  : arrayofpar;
   c    : pnode;
begin
   m := length(children);
   how := table.reconstruct(k);

   for i:=0 to m-1 do begin (* rekonstruiram djecu koja su neovisna o meni *)
      c := children[i];
      if how[i].first = 0 then c^.reconstruct(how[i].second);
   end;

   for i:=0 to m-1 do begin (* rekonstruiram djecu koja ce mi dati novac *)
      c := children[i];
      if (how[i].first = 1) and (c^.dp[how[i].second] >= 0) then begin
         c^.reconstruct(how[i].second);
         writeln(c^.index, ' ', index, ' ', c^.dp[how[i].second]);
      end;
   end;

   for i:=0 to m-1 do begin (* rekonstruiram djecu kojoj moram dati novac *)
      c := children[i];
      if (how[i].first = 1) and (c^.dp[how[i].second] < 0) then begin
         writeln(index, ' ', c^.index, ' ', -c^.dp[how[i].second]);
         c^.reconstruct(how[i].second);
      end;
   end;
end;

var a : array[0..MAXN] of node;

procedure build_and_solve(u, dad : longint);
var
   i         : longint;
   nchildren : longint;
begin
   a[u].size := 1;
   a[u].index := u+1;
   nchildren := 0;
   for i:=0 to adj[u].n-1 do begin
      if adj[u].elem[i] = dad then continue;

      build_and_solve(adj[u].elem[i], u);
      inc(nchildren);
   end;
   setlength(a[u].children, nchildren);
   
   nchildren := 0;
   for i:=0 to adj[u].n-1 do begin
      if adj[u].elem[i] = dad then continue;

      a[u].children[nchildren] := @a[adj[u].elem[i]];
      inc(a[u].size, a[adj[u].elem[i]].size);
      inc(nchildren);
   end;
   a[u].solve;
end;

var
   i, c, d, ret : longint;

begin
   read(n);
   read(x);
   for i:=0 to n-1 do read(a[i].target);

   for i:=1 to n-1 do begin
      read(c, d); dec(c); dec(d);
      adj[c].add(d);
      adj[d].add(c);
   end;

   build_and_solve(0, -1);

   ret := 0;
   while a[0].dp[ret] < 0 do inc(ret);
   writeln(ret);

   a[0].reconstruct(ret);
end.
