#include <algorithm>
#include <cstdio>

using namespace std;

typedef long long llint;

#define MAXN 2000

struct point { 
   int x, y; 
   char color;
   int pos;
} P[MAXN];
bool operator < ( const point &A, const point &B ) { return A.x != B.x ? A.x < B.x : A.y < B.y; }

struct segment { 
   point *A, *B;
   int dx, dy;
   segment() {}
   segment( point *a, point *b ) {
      A = a; B = b;
      dx = B->x - A->x;
      dy = B->y - A->y;
   }
} S[MAXN*MAXN/2];
bool operator < ( const segment &A, const segment &B ) { return (llint)A.dy * B.dx < (llint)B.dy * A.dx; }

struct node { int left, right, best, full; } tree[1<<13];

void tree_update( int i, int lo, int hi, int x, int val ) {
   if( x < lo || x >= hi ) return;
   if( hi-lo == 1 ) {
      tree[i].left = tree[i].right = tree[i].best = tree[i].full = (val==0);
   } else {
      tree_update( 2*i, lo, (lo+hi)/2, x, val );
      tree_update( 2*i+1, (lo+hi)/2, hi, x, val );

      tree[i].full = tree[2*i].full && tree[2*i+1].full;
      tree[i].left = tree[2*i].full ? tree[2*i].left + tree[2*i+1].left : tree[2*i].left;
      tree[i].right = tree[2*i+1].full ? tree[2*i+1].right + tree[2*i].right : tree[2*i+1].right;
      tree[i].best = max( tree[2*i].right + tree[2*i+1].left, max( tree[2*i].best, tree[2*i+1].best ) );
   }
}

int main( void ) {
   int n, m = 0;
   scanf( "%d", &n );
   for( int i = 0; i < n; ++i ) scanf( "%d%d %c", &P[i].x, &P[i].y, &P[i].color );
   sort( P, P+n );
   for( int i = 0; i < n; ++i ) {
      P[i].pos = i;
      tree_update( 1, 0, n, i, P[i].color == 'B' );
   }

   for( int i = 0; i < n; ++i ) 
      for( int j = i+1; j < n; ++j ) 
         S[m++] = segment( P+i, P+j );
   sort( S, S+m );

   int ret = tree[1].best;

   for( int i = 0, j; i < m; i = j ) {
      for( j = i; j < m && !(S[i]<S[j]); ++j ) {
         swap( S[j].A->pos, S[j].B->pos );
         tree_update( 1, 0, n, S[j].A->pos, S[j].A->color == 'B' );
         tree_update( 1, 0, n, S[j].B->pos, S[j].B->color == 'B' );
      }
      ret = max( ret, tree[1].best );
   }

   printf( "%d\n", ret );
   
   return 0;
}
