#include <algorithm>
#include <cstdio>
#include <ctime>

using namespace std;

const int oo = 0x3FFFFFFF;

#define MAXN 100
#define MAXK 10
#define MAXP 1000000
#define MAXRUBOVA 4*(MAXK-1)
#define BIJELO 'w'
#define CRVENO 'r'

const int dr[4] = { -1, 0, 1, 0 };
const int ds[4] = { 0, 1, 0, -1 };
inline int smjer( char c ) { 
   if( c == 'U' ) return 0;
   if( c == 'R' ) return 1;
   if( c == 'D' ) return 2;
   if( c == 'L' ) return 3;
   throw 1;
}
int N, K, P;
char dno[MAXN][MAXN+1];
int dist[MAXN][MAXN][MAXRUBOVA][MAXRUBOVA];

char unutar[MAXK][MAXK];
int bfs_dist[MAXK][MAXK];
int qhead, qtail;
int queue_r[MAXK*MAXK], queue_s[MAXK*MAXK];

int rubova;
int rub_r[MAXRUBOVA], rub_s[MAXRUBOVA];
int rub[4][MAXK];
int indeks[MAXK][MAXK];

int R, S;
char potezi[MAXP+1];

void generiraj_rubove() {
   rubova = 0;
   for( int r = 0; r < K; ++r ) 
      for( int s = 0; s < K; ++s ) 
         if( r > 0 && r < K-1 && s > 0 && s < K-1 ) {
            indeks[r][s] = -1;
         } else {
            rub_r[rubova] = r;
            rub_s[rubova] = s;
            indeks[r][s] = rubova++;
         }

   for( int s = 0; s < K; ++s ) rub[0][s] = indeks[0][s];
   for( int r = 0; r < K; ++r ) rub[1][r] = indeks[r][K-1];
   for( int s = 0; s < K; ++s ) rub[2][s] = indeks[K-1][s];
   for( int r = 0; r < K; ++r ) rub[3][r] = indeks[r][0];
}

void bfs( int r0, int s0, int *ret ) {
   for( int r = 0; r < K; ++r ) 
      for( int s = 0; s < K; ++s ) 
         bfs_dist[r][s] = oo;

   qhead = qtail = 0;
   
   if( unutar[r0][s0] == BIJELO ) bfs_dist[r0][s0] = 0;
   queue_r[qtail] = r0;
   queue_s[qtail] = s0;
   ++qtail;

   while( qhead != qtail ) {
      int r = queue_r[qhead];
      int s = queue_s[qhead];
      ++qhead;
      
      for( int d = 0; d < 4; ++d ) {
         int rr = r+dr[d];
         int ss = s+ds[d];
         if( rr < 0 || rr >= K ) continue;
         if( ss < 0 || ss >= K ) continue;
         if( unutar[rr][ss] == CRVENO ) continue;
         if( bfs_dist[rr][ss] <= bfs_dist[r][s] + 1 ) continue;
         bfs_dist[rr][ss] = bfs_dist[r][s] + 1;
         
         queue_r[qtail] = rr;
         queue_s[qtail] = ss;
         ++qtail;
      }
   }   
   
   for( int i = 0; i < rubova; ++i ) ret[i] = bfs_dist[ rub_r[i] ][ rub_s[i] ];
}

void generiraj_distove() {
   for( int r0 = 0; r0+K <= N; ++r0 ) 
      for( int s0 = 0; s0+K <= N; ++s0 ) {
         for( int r = 0; r < K; ++r ) 
            for( int s = 0; s < K; ++s ) 
               unutar[r][s] = dno[r0+r][s0+s];

         for( int i = 0; i < rubova; ++i ) 
            bfs( rub_r[i], rub_s[i], dist[r0][s0][i] );
      }
}

int rijesi() {
   int dp[2][MAXK];
   
   int *curr_dp = dp[0];
   int *next_dp = dp[1];
   int *curr_indeks = rub[ smjer(potezi[0]) ];

   for( int i = 0; i < K; ++i ) curr_dp[i] = dno[R+rub_r[curr_indeks[i]]][S+rub_s[curr_indeks[i]]] == BIJELO ? 0 : oo;
   
   for( int pp = 0; pp < P; ++pp ) {
      int d = smjer(potezi[pp]);
      int *next_indeks = rub[d];
      
      for( int i = 0; i < K; ++i ) next_dp[i] = oo;

      for( int i = 0; i < K; ++i )
         for( int j = 0; j < K; ++j )
            next_dp[j] = min( next_dp[j], curr_dp[i] + dist[R][S][curr_indeks[i]][next_indeks[j]] );
      
      R += dr[d];
      S += ds[d];

      for( int i = 0; i < K; ++i ) {
         next_dp[i] = min( next_dp[i] + 1, oo );
         if( dno[R+rub_r[next_indeks[i]]][S+rub_s[next_indeks[i]]] == CRVENO ) next_dp[i] = oo; 
      }

      swap( curr_dp, next_dp );
      curr_indeks = next_indeks;
   }

   int ret = oo;
   for( int i = 0; i < K; ++i ) ret = min( ret, curr_dp[i] );
   return ret;
}

int main( void ) {
   scanf( "%d%d", &N, &K );
   for( int i = 0; i < N; ++i ) scanf( "%s", dno[i] );

   generiraj_rubove();
   generiraj_distove();
   
   scanf( "%d%d", &R, &S ); --R; --S;
   scanf( "%d ", &P );
   gets( potezi );

   printf( "%d\n", rijesi() );
   
   return 0;
}
