/* sub
 *
 * P: Se dau doua multimi de siruri A si B. Sa se gaseasca cel mai scurt sir 
 * care este subsecventa al tuturor sirurilor din multimea A, dar nu este
 * subsecventa al nici unui sir din multimea B.
 *
 * S: Se construieste un arbore de prefixe al tuturor subsecventelor de lungime
 * min_len ale sirurilor din A (unde min_len este lungimea celui mai scurt sir
 * din A). Similar, pentru subsecventele sirurilor din B, se marcheaza in
 * arborele de prefixe construit nodurile ca fiind "invalide". La sfarsit se
 * verifica numarul nodurilor valide.
 *
 * Complexitate: O(([A] + [B]) * min_len), unde [A] este suma
 * lungimilor tuturor sirurilor din A
 *
 * Tiberiu Danet, Apr 2008
 */

#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#define MAX_LEN 512
#define MAX_NUM 128

int Na, Nb;
char *Sa[MAX_NUM];

struct node {
    char c;
    short flag;
    struct node *son, *brother;
};

struct node *Root;

int P;
int Ans;

void trie_insert(char *s, int start, int end) {
    struct node *n, *np, *nw;
    
    n = Root;
    for (; start < end; ++start) {
        if (n->son == NULL) {
            nw = (struct node *)malloc(sizeof(struct node));
            nw->c = s[start];
            nw->son = NULL;
            nw->brother = NULL;
            // nw->flag = 1;
            nw->flag = P;
            n->son = nw;
            n = nw;
        } else {
            for (n = n->son; n; np = n, n = n->brother)
                if (n->c == s[start]) {
                    // n->flag++;
                    if (n->flag * P < 0)
                        n->flag = -n->flag + P;
                    break;
                }
                
            if (n == NULL) {
                nw = (struct node *)malloc(sizeof(struct node));
                nw->c = s[start];
                nw->son = NULL;
                nw->brother = NULL;
                // nw->flag = 1;
                nw->flag = P;
                np->brother = nw;
                n = nw;
            }
        }
    }
}

void trie_erase(char *s, int start, int end) {
    struct node *n;
    
    n = Root;
    for (; start < end; ++start) {
        for (n = n->son; n; n = n->brother)
            if (n->c == s[start]) {
                if (n->flag == -Na || n->flag == Na)
                    n->flag = MAX_LEN + 1;
                break;
            }
            
         if (n == NULL)
            break;
    }
}

void trie_find_answer(struct node *n) {
    for (n = n->son; n; n = n->brother) {
        if (n->flag == Na || n->flag == -Na) {
            Ans++;
            trie_find_answer(n);
        } else if (n->flag == MAX_LEN + 1) {
            trie_find_answer(n);
        }
    }
}

void read_solve() {
    char s[MAX_LEN];
    int i, j, l;
    int min_len = -1;
    
    Root = (struct node *)malloc(sizeof(struct node));
    Root->c = ' ';
    Root->flag = 0;
    Root->son = NULL;
    Root->brother = NULL;
    
    freopen("sub.in", "r", stdin);
    scanf("%d", &Na);
    for (i = 0; i < Na; ++i) {
        scanf("%s", &s);
        l = strlen(s);
        Sa[i] = (char *)malloc((l + 1) * sizeof(char));
        strcpy(Sa[i], s);
        if (min_len == -1 || min_len > l)
            min_len = l;
    }
    
    P = 1;
    for (i = 0; i < Na; ++i) {
        l = strlen(Sa[i]);
        for (j = 0; j < l; ++j)
            trie_insert(Sa[i], j, (j + min_len > l ? l : j + min_len));
        P *= -1;
    }
    
    scanf("%d", &Nb);
    for (i = 0; i < Nb; ++i) {
        scanf("%s", &s);
        l = strlen(s);
        for (j = 0; j < l; ++j)
            trie_erase(s, j, (j + min_len > l ? l : j + min_len));
    }    
    
    trie_find_answer(Root);
    
    freopen("sub.out", "w", stdout);
    printf("%d\n", Ans);
}

int main() {
    read_solve();
    return 0;
}

