#include <cstdio>

typedef short int WORD;

#define MAX_M 512
#define MAX_N 128

WORD X[MAX_M][MAX_M];
WORD P[MAX_N][MAX_N];
char match[MAX_M][MAX_M];
int N,M;

void Compute_Prefix(WORD *P,WORD *pref, int N)
{
	pref[0] = 0;
	for (int i=1;i<N;i++)
	{
		pref[i]=0;
		int k=pref[i-1];
		while (k>0)
		{
			if (P[k]==P[i])
			{
				pref[i]=k+1;
				break;
			}
			k=pref[k-1];
		}

		if (pref[i]==0&&P[i]==P[0]) pref[i]=1;
	}
}

void KMP(WORD* T,WORD *P,int M,int N,int a)//the match is stored in match+a+i;
{
	short int prefix[MAX_N];

	Compute_Prefix(P,prefix,N);

	//KMP
	int k=0;

	for (int i=0;i<M;i++)
	{
		if (P[k]==T[i])
		{
			k++;
			if (k==N)
			{
				//match
				k=prefix[k-1];
				match[a][i-N+1] ++;
			}
		}
		else
		{
			if (k>0)
			{
				k=prefix[k-1];
				i--;
			}
		}
	}
}

void read_data()
{
	FILE *f=fopen ("tetris.in","r");
	fscanf (f,"%d",&M);

	for (int i=0;i<M;i++)
		for (int j=0;j<M;j++)
			fscanf (f,"%d",&X[i][j]);

	fscanf (f,"%d",&N);

	for (int i=0;i<N;i++)
		for (int j=0;j<N;j++)
			fscanf (f,"%d",&P[i][j]);

	fclose (f);
}

void Transpose(WORD *P,int n,int stride)
{
	for (int i=0;i<n;i++)
		for (int j=i+1;j<n;j++)
		{
			WORD aux=*(P+i*stride+j);
			*(P+i*stride+j)=*(P+j*stride+i);
			*(P+j*stride+i)=aux;
		}
}

void Transpose(char *P,int n,int stride)
{
	for (int i=0;i<n;i++)
		for (int j=i+1;j<n;j++)
		{
			char aux=*(P+i*stride+j);
			*(P+i*stride+j)=*(P+j*stride+i);
			*(P+j*stride+i)=aux;
		}
}

void solve()
{
	if (N==1)
	{
		fprintf (fopen ("tetris.out","w"),"%d\n",M*M);
		return;
	}

	//compute differences
	for (int i=0;i<M;i++)
		for (int j=M-1;j>0;j--)
			X[i][j]=-(X[i][j]-X[i][j-1]);

	for (int i=0;i<N;i++)
		for (int j=N-1;j>0;j--)
			P[i][j]=P[i][j]-P[i][j-1];

	//KMP
	for (int i=0;i<N;i++)
		for (int j=i;j<M;j++)		
			KMP(X[j]+1,P[i]+1,M-1,N-1,j-i);
	
	//remake 

	for (int i=0;i<M;i++)
		for (int j=1;j<M;j++)
			X[i][j]=X[i][j-1]-X[i][j];

	for (int i=0;i<N;i++)
		for (int j=1;j<N;j++)
			P[i][j]+=P[i][j-1];

	//transpose

	Transpose((WORD*)X,M,MAX_M);
	Transpose((WORD*)P,N,MAX_N);
	Transpose((char*)match,M,MAX_M);

	//compute differences
	for (int i=0;i<M;i++)
		for (int j=M-1;j>0;j--)
			X[i][j]=-(X[i][j]-X[i][j-1]);

	for (int i=0;i<N;i++)
		for (int j=N-1;j>0;j--)
			P[i][j]=P[i][j]-P[i][j-1];

	//KMP
	for (int j=0;j<M;j++)
		KMP(X[j]+1,P[0]+1,M-1,N-1,j);

	int rez=0;
	for (int i=0;i<M;i++)
		for (int j=0;j<M;j++)
			if (match[i][j]==N+1) 
				rez++;

	fprintf (fopen ("tetris.out","w"),"%d\n",rez);
}

int main()
{
	read_data();
	solve();

	return 0;
}