#include <stdio.h>

#include <algorithm>
#include <vector>

using namespace std;

#define NMAX 2010

vector<pair<double, int> > nosort, revsort, vddesc, vdasc, T1min, T2max, vasc, vdesc, dasc, ddesc, dlendesc, dlenasc, vdlendesc, vdlenasc;
int T1[NMAX], T2[NMAX], d[NMAX], v[NMAX], tstart[NMAX], used[NMAX];
int i, j, k, N, Tmin, vmax, vnew, sum;

int greedy1(vector<pair<double, int> > *order, char *str)
{
	int vsum = 0, Tmin, intersecting = 0;

	sort(order->begin(), order->end());

	// select the sensors in the greedy order
	memset(used, 0, sizeof(used));
	memset(tstart, 0, sizeof(tstart));

	for (i = 0; i < N; i++)
	{
		k = (*order)[i].second;

		// place k as early as possible (if possible)
		Tmin = T1[k];

		intersecting = 1;

		while (intersecting)
		{
			intersecting = 0;

			if (k > 1 && used[k - 1])
			{
				if (
					((tstart[k - 1] <= Tmin) && (Tmin < (tstart[k - 1] + d[k - 1]))) ||
				    ((tstart[k - 1] < (Tmin + d[k])) && ((Tmin + d[k]) <= (tstart[k - 1] + d[k - 1]))) ||
				    ((Tmin <= tstart[k - 1]) && (tstart[k - 1] < (Tmin + d[k]))) ||
				    ((Tmin < (tstart[k - 1] + d[k - 1])) && ((tstart[k - 1] + d[k - 1]) <= (Tmin + d[k])))
				   )
				{
					// choose a different Tmin
					Tmin = tstart[k - 1] + d[k - 1];
					intersecting = 1;
				}
			}

			if (k < N && used[k + 1])
			{
				if (
					((tstart[k + 1] <= Tmin) && (Tmin < (tstart[k + 1] + d[k + 1]))) ||
				    ((tstart[k + 1] < (Tmin + d[k])) && ((Tmin + d[k]) <= (tstart[k + 1] + d[k + 1]))) ||
				    ((Tmin <= tstart[k + 1]) && (tstart[k + 1] < (Tmin + d[k]))) ||
				    ((Tmin < (tstart[k + 1] + d[k + 1])) && ((tstart[k + 1] + d[k + 1]) <= (Tmin + d[k])))
				   )
				{
					// choose a different Tmin
					Tmin = tstart[k + 1] + d[k + 1];
					intersecting = 1;
				}
			}
		}

		if (Tmin + d[k] <= T2[k])
		{
			used[k] = 1;
			tstart[k] = Tmin;
			vsum += v[k];
		}
	}

	// check the interval assignment

	for (i = 1; i < N; i++)
		if (used[i] && used[i + 1])
		{
			if (
				( ( tstart[i] <= tstart[i + 1] ) && ( tstart[i + 1] < ( tstart[i] + d[i] ) ) ) ||
			    ( ( tstart[i] < (tstart[i + 1] + d[i + 1] ) ) && ( ( tstart[i + 1] + d[i + 1] ) <= ( tstart[i] + d[i] ) ) ) ||
				( ( tstart[i + 1] <= tstart[i] ) && ( tstart[i] < ( tstart[i + 1] + d[i + 1] ) ) ) ||
			    ( ( tstart[i + 1] < ( tstart[i] + d[i] ) ) && ( ( tstart[i] + d[i] ) <= ( tstart[i + 1] + d[i + 1] ) ) )
			   )
			   fprintf(stderr, "bad assignment: %d,%d -> [%d,%d] and [%d,%d]\n", i, i+1, tstart[i], tstart[i] + d[i], tstart[i+1], tstart[i+1] + d[i+1]);
		}

	fprintf(stderr, "(as early as possible) %s: %d\n", str, vsum);

	if (vsum > vmax)
		vmax = vsum;

	return vsum;
}

int greedy2(vector<pair<double, int> > *order, char *str)
{
	int vsum = 0, Tmax, intersecting = 0;

	sort(order->begin(), order->end());

	// select the sensors in the greedy order
	memset(used, 0, sizeof(used));
	memset(tstart, 0, sizeof(tstart));

	for (i = 0; i < N; i++)
	{
		k = (*order)[i].second;

		// place k as late as possible (if possible)
		Tmax = T2[k];

		intersecting = 1;

		while (intersecting)
		{
			intersecting = 0;

			if (k > 1 && used[k - 1])
			{
				if (
					((tstart[k - 1] < Tmax) && (Tmax <= (tstart[k - 1] + d[k - 1]))) ||
				    ((tstart[k - 1] <= (Tmax - d[k])) && ((Tmax - d[k]) < (tstart[k - 1] + d[k - 1]))) ||
				    (((Tmax - d[k]) <= tstart[k - 1]) && (tstart[k - 1] < Tmax)) ||
				    (((Tmax - d[k]) < (tstart[k - 1] + d[k - 1])) && ((tstart[k - 1] + d[k - 1]) <= Tmax))
				   )
				{
					// choose a different Tmax
					Tmax = tstart[k - 1];
					intersecting = 1;
				}
			}

			if (k < N && used[k + 1])
			{
				if (
					((tstart[k + 1] < Tmax) && (Tmax <= (tstart[k + 1] + d[k + 1]))) ||
				    ((tstart[k + 1] <= (Tmax - d[k])) && ((Tmax - d[k]) < (tstart[k + 1] + d[k + 1]))) ||
				    (((Tmax - d[k]) <= tstart[k + 1]) && (tstart[k + 1] < Tmax)) ||
				    (((Tmax - d[k]) < (tstart[k + 1] + d[k + 1])) && ((tstart[k + 1] + d[k + 1]) <= Tmax))
				   )
				{
					// choose a different Tmax
					Tmax = tstart[k + 1];
					intersecting = 1;
				}
			}
		}

		if (Tmax - d[k] >= T1[k])
		{
			used[k] = 1;
			tstart[k] = Tmax - d[k];
			vsum += v[k];
		}
	}

	// check the interval assignment

	for (i = 1; i < N; i++)
		if (used[i] && used[i + 1])
		{
			if (
				( ( tstart[i] <= tstart[i + 1] ) && ( tstart[i + 1] < ( tstart[i] + d[i] ) ) ) ||
			    ( ( tstart[i] < (tstart[i + 1] + d[i + 1] ) ) && ( ( tstart[i + 1] + d[i + 1] ) <= ( tstart[i] + d[i] ) ) ) ||
				( ( tstart[i + 1] <= tstart[i] ) && ( tstart[i] < ( tstart[i + 1] + d[i + 1] ) ) ) ||
			    ( ( tstart[i + 1] < ( tstart[i] + d[i] ) ) && ( ( tstart[i] + d[i] ) <= ( tstart[i + 1] + d[i + 1] ) ) )
			   )
			   fprintf(stderr, "bad assignment: %d,%d -> [%d,%d] and [%d,%d]\n", i, i+1, tstart[i], tstart[i] + d[i], tstart[i+1], tstart[i+1] + d[i+1]);
		}

	fprintf(stderr, "(as late as possible) %s: %d\n", str, vsum);

	if (vsum > vmax)
		vmax = vsum;

	return vsum;
}

int greedy3(vector<pair<double, int> > *order, char *str)
{
	int vsum = 0, Tmin, Tmax, intersecting = 0;

	sort(order->begin(), order->end());

	// select the sensors in the greedy order
	memset(used, 0, sizeof(used));
	memset(tstart, 0, sizeof(tstart));

	for (i = 0; i < N; i++)
	{
		k = (*order)[i].second;

		if (rand() % 2 == 0)
		{
			// place k as early as possible (if possible)
			Tmin = T1[k];

			intersecting = 1;

			while (intersecting)
			{
				intersecting = 0;

				if (k > 1 && used[k - 1])
				{
					if (
						((tstart[k - 1] <= Tmin) && (Tmin < (tstart[k - 1] + d[k - 1]))) ||
					    ((tstart[k - 1] < (Tmin + d[k])) && ((Tmin + d[k]) <= (tstart[k - 1] + d[k - 1]))) ||
					    ((Tmin <= tstart[k - 1]) && (tstart[k - 1] < (Tmin + d[k]))) ||
					    ((Tmin < (tstart[k - 1] + d[k - 1])) && ((tstart[k - 1] + d[k - 1]) <= (Tmin + d[k])))
					   )
					{
						// choose a different Tmin
						Tmin = tstart[k - 1] + d[k - 1];
						intersecting = 1;
					}
				}

				if (k < N && used[k + 1])
				{
					if (
						((tstart[k + 1] <= Tmin) && (Tmin < (tstart[k + 1] + d[k + 1]))) ||
					    ((tstart[k + 1] < (Tmin + d[k])) && ((Tmin + d[k]) <= (tstart[k + 1] + d[k + 1]))) ||
					    ((Tmin <= tstart[k + 1]) && (tstart[k + 1] < (Tmin + d[k]))) ||
					    ((Tmin < (tstart[k + 1] + d[k + 1])) && ((tstart[k + 1] + d[k + 1]) <= (Tmin + d[k])))
					   )
					{
						// choose a different Tmin
						Tmin = tstart[k + 1] + d[k + 1];
						intersecting = 1;
					}
				}
			}

			if (Tmin + d[k] <= T2[k])
			{
				used[k] = 1;
				tstart[k] = Tmin;
				vsum += v[k];
			}
		}
		else
		{
			// place k as late as possible (if possible)
			Tmax = T2[k];

			intersecting = 1;

			while (intersecting)
			{
				intersecting = 0;

				if (k > 1 && used[k - 1])
				{
					if (
						((tstart[k - 1] < Tmax) && (Tmax <= (tstart[k - 1] + d[k - 1]))) ||
					    ((tstart[k - 1] <= (Tmax - d[k])) && ((Tmax - d[k]) < (tstart[k - 1] + d[k - 1]))) ||
					    (((Tmax - d[k]) <= tstart[k - 1]) && (tstart[k - 1] < Tmax)) ||
					    (((Tmax - d[k]) < (tstart[k - 1] + d[k - 1])) && ((tstart[k - 1] + d[k - 1]) <= Tmax))
					   )
					{
						// choose a different Tmax
						Tmax = tstart[k - 1];
						intersecting = 1;
					}
				}

				if (k < N && used[k + 1])
				{
					if (
						((tstart[k + 1] < Tmax) && (Tmax <= (tstart[k + 1] + d[k + 1]))) ||
					    ((tstart[k + 1] <= (Tmax - d[k])) && ((Tmax - d[k]) < (tstart[k + 1] + d[k + 1]))) ||
					    (((Tmax - d[k]) <= tstart[k + 1]) && (tstart[k + 1] < Tmax)) ||
					    (((Tmax - d[k]) < (tstart[k + 1] + d[k + 1])) && ((tstart[k + 1] + d[k + 1]) <= Tmax))
					   )
					{
						// choose a different Tmax
						Tmax = tstart[k + 1];
						intersecting = 1;
					}
				}
			}

			if (Tmax - d[k] >= T1[k])
			{
				used[k] = 1;
				tstart[k] = Tmax - d[k];
				vsum += v[k];
			}
		}
	}

	// check the interval assignment

	for (i = 1; i < N; i++)
		if (used[i] && used[i + 1])
		{
			if (
				( ( tstart[i] <= tstart[i + 1] ) && ( tstart[i + 1] < ( tstart[i] + d[i] ) ) ) ||
			    ( ( tstart[i] < (tstart[i + 1] + d[i + 1] ) ) && ( ( tstart[i + 1] + d[i + 1] ) <= ( tstart[i] + d[i] ) ) ) ||
				( ( tstart[i + 1] <= tstart[i] ) && ( tstart[i] < ( tstart[i + 1] + d[i + 1] ) ) ) ||
			    ( ( tstart[i + 1] < ( tstart[i] + d[i] ) ) && ( ( tstart[i] + d[i] ) <= ( tstart[i + 1] + d[i + 1] ) ) )
			   )
			   fprintf(stderr, "bad assignment: %d,%d -> [%d,%d] and [%d,%d]\n", i, i+1, tstart[i], tstart[i] + d[i], tstart[i+1], tstart[i+1] + d[i+1]);
		}

	fprintf(stderr, "(random early/late) %s: %d\n", str, vsum);

	if (vsum > vmax)
		vmax = vsum;

	return vsum;
}

int main()
{
	freopen("senzori.in", "r", stdin);
	scanf("%d", &N);

	for (sum = 0, i = 1; i <= N; i++)
	{
		scanf("%d %d %d %d", &T1[i], &T2[i], &d[i], &v[i]);
		sum += v[i];
	}

	fprintf(stderr, "total value sum: %d\n", sum);

	// build the greedy arrays
	for (i = 1; i <= N; i++)
	{
		nosort.push_back(make_pair(i, i));
		revsort.push_back(make_pair(-i, i));
		vddesc.push_back(make_pair(-(double) v[i] / (double) d[i], i));
		vdasc.push_back(make_pair((double) v[i] / (double) d[i], i));
		T1min.push_back(make_pair((double) T1[i], i));
		T2max.push_back(make_pair(- (double) T2[i], i));
		vasc.push_back(make_pair((double) v[i], i));
		vdesc.push_back(make_pair(- (double) v[i], i));
		dasc.push_back(make_pair((double) d[i], i));
		ddesc.push_back(make_pair(- (double) d[i], i));
		dlendesc.push_back(make_pair(- (double) d[i] / (double) (T2[i] - T1[i]), i));
		dlenasc.push_back(make_pair((double) d[i] / (double) (T2[i] - T1[i]), i));
		vdlendesc.push_back(make_pair(- (double) v[i] * (double) d[i] / (double) (T2[i] - T1[i]), i));
		vdlenasc.push_back(make_pair((double) v[i] * (double) d[i] / (double) (T2[i] - T1[i]), i));
	}

	vmax = 0;

	greedy1(&nosort, "no sort");
	greedy1(&revsort, "reverse sort");
	greedy1(&vddesc, "v[i]/d[i] descending");
	greedy1(&vdasc, "v[i]/d[i] ascending");
	greedy1(&T1min, "T1[i] ascending");
	greedy1(&T2max, "T2[i] descending");
	greedy1(&vasc, "v[i] ascending");
	greedy1(&vdesc, "v[i] descending");
	greedy1(&dasc, "d[i] ascending");
	greedy1(&ddesc, "d[i] descending");
	greedy1(&dlendesc, "d[i]/(T2[i]-T1[i]) descending");
	greedy1(&dlenasc, "d[i]/(T2[i]-T1[i]) ascending");
	greedy1(&vdlendesc, "v[i]*d[i]/(T2[i]-T1[i]) descending");
	greedy1(&vdlenasc, "v[i]*d[i]/(T2[i]-T1[i]) ascending");

	greedy2(&nosort, "no sort");
	greedy2(&revsort, "reverse sort");
	greedy2(&vddesc, "v[i]/d[i] descending");
	greedy2(&vdasc, "v[i]/d[i] ascending");
	greedy2(&T1min, "T1[i] ascending");
	greedy2(&T2max, "T2[i] descending");
	greedy2(&vasc, "v[i] ascending");
	greedy2(&vdesc, "v[i] descending");
	greedy2(&dasc, "d[i] ascending");
	greedy2(&ddesc, "d[i] descending");
	greedy2(&dlendesc, "d[i]/(T2[i]-T1[i]) descending");
	greedy2(&dlenasc, "d[i]/(T2[i]-T1[i]) ascending");
	greedy2(&vdlendesc, "v[i]*d[i]/(T2[i]-T1[i]) descending");
	greedy2(&vdlenasc, "v[i]*d[i]/(T2[i]-T1[i]) ascending");

	greedy3(&nosort, "no sort");
	greedy3(&revsort, "reverse sort");
	greedy3(&vddesc, "v[i]/d[i] descending");
	greedy3(&vdasc, "v[i]/d[i] ascending");
	greedy3(&T1min, "T1[i] ascending");
	greedy3(&T2max, "T2[i] descending");
	greedy3(&vasc, "v[i] ascending");
	greedy3(&vdesc, "v[i] descending");
	greedy3(&dasc, "d[i] ascending");
	greedy3(&ddesc, "d[i] descending");
	greedy3(&dlendesc, "d[i]/(T2[i]-T1[i]) descending");
	greedy3(&dlenasc, "d[i]/(T2[i]-T1[i]) ascending");
	greedy3(&vdlendesc, "v[i]*d[i]/(T2[i]-T1[i]) descending");
	greedy3(&vdlenasc, "v[i]*d[i]/(T2[i]-T1[i]) ascending");

	fprintf(stderr, "vmax=%d\n", vmax);

	freopen("senzori.out", "w", stdout);
	printf("%d\n", vmax);

	return 0;
}
