#include <stdio.h>
#include <math.h>

#define NMAX 1000100
#define INF (x[N] + 10)
#define eps 1e-6
#define DOUBLE_INF 1e17

long long x[NMAX], xrtol[NMAX], w[NMAX], wrtol[NMAX], A, B, C, D;
double xcue[2][NMAX << 1], dqxlast[NMAX], xcross, dwmin, xpos;
int nc[2], fidxue[2][NMAX << 1], dqidx[NMAX], li, ls;
int i, j, k, N, L, np;

void upper_envelope(long long *xp, long long *wp, double *xue, int *fidue, int &num)
{
	int i, k;

	num = 1;
	xue[1] = xp[1];
	fidue[1] = 1;
	dqidx[li = ls = 1] = 1;
	dqxlast[1] = INF;
	dqxlast[0] = xp[1] - 1;

	i = 2;
	while (i <= N)
	{
		if (xp[i] < dqxlast[li])
		{
			if (wp[i] > wp[dqidx[ls]])
			{
				// consider the function fi
				while (ls - li + 1 > 0)
				{
					xcross = xp[i] + (double) (wp[dqidx[ls]] * (xp[i] - xp[dqidx[ls]])) / (wp[i] - wp[dqidx[ls]]);
					if (xcross > INF)
						xcross = INF;

					if (xcross < dqxlast[ls - 1] || fabs(xcross - dqxlast[ls - 1]) < eps)
						ls--;
					else
					{
						if (xcross < dqxlast[ls])
							dqxlast[ls] = xcross;
						break;
					}
				}

				ls++;
				dqidx[ls] = i;
				dqxlast[ls] = INF;
			}

			num++;
			xue[num] = xp[i];
			fidue[num] = dqidx[li];

			i++;
		}
		else
		{
			num++;
			xue[num] = dqxlast[li];
			li++;
			fidue[num] = dqidx[li];
		}
	}

	for (k = 1, i = 2; i < num; i++)
		if (fidue[i] == fidue[k])
			xue[k + 1] = xue[i + 1];
		else
		{
			k++;
			xue[k] = xue[i];
			fidue[k] = fidue[i];
		}

	k++;
	xue[k] = xue[num];
	num = k;
}

void upper_envelope_LtoR(void)
{
	upper_envelope(x, w, xcue[0], fidxue[0], nc[0]);

	fprintf(stderr, "Upper Envelope (Left to Right)\nnum_points=%d\n", nc[0]);
	
	/*
	for (i = 1; i < nc[0]; i++)
		fprintf(stderr, "%d: [%.4lf - %.4lf] -> fidxue=%d\n", i, xcue[0][i], xcue[0][i + 1], fidxue[0][i]);
	*/
}

void upper_envelope_RtoL(void)
{
	int i, j, M;
	double vaux;

	for (i = 1; i <= N; i++)
	{
		xrtol[i] = -x[N - i + 1];
		wrtol[i] = w[N - i + 1];
	}

	upper_envelope(xrtol, wrtol, xcue[1], fidxue[1], nc[1]);

	for (i = 1, M = nc[1] / 2; i <= M; i++)
	{
		// swap xcue[1][i] with xcue[1][nc[1] - i + 1] and change sign
		vaux = -xcue[1][i];
		xcue[1][i] = - xcue[1][nc[1] - i + 1];
		xcue[1][nc[1] - i + 1] = vaux;

		// swap fidxue[1][i] with fidx[1][nc[1] - i + 1] and mirror
		j = fidxue[1][i];
		fidxue[1][i] = N - fidxue[1][nc[1] - i + 1] + 1;
		fidxue[1][nc[1] - i + 1] = N - j + 1;
	}

	if (nc[1] % 2 == 1)
		xcue[1][M + 1] = -xcue[1][M + 1],
		fidxue[1][M + 1] = N - fidxue[1][M + 1] + 1;

	for (i = 2; i <= nc[1]; i++)
		fidxue[1][i - 1] = fidxue[1][i];

	fprintf(stderr, "Upper Envelope (Rigth to Left)\nnum_points=%d\n", nc[1]);
	
	/*
	for (i = 1; i < nc[1]; i++)
		fprintf(stderr, "%d: [%.4lf - %.4lf] -> fidxue=%d\n", i, xcue[1][i], xcue[1][i + 1], fidxue[1][i]);
	*/
}

void center_traversal(void)
{
	int i, j, f, g, fsol, gsol, local_dwmin_type, dwmin_type;
	double xleft, xright, dleft, dright, dmin, local_dwmin, local_xpos;

	dwmin = DOUBLE_INF;

	i = j = 1;
	xleft = xcue[0][1];
		xright = xleft + L;

	while (1)
	{
		if (i >= nc[0])
			break;
		
		while (j <= nc[1] && (xcue[1][j] < xright || fabs(xcue[1][j] - xright) < eps))
			j++;

		if (xcue[1][j] < xright || fabs(xcue[1][j] - xright) < eps)
			break;

		// the left endpoint is in the interval [xleft, xcue[0][i + 1]]
		// the right endpoint is in the interval [xright, xcue[1][j]]

		dleft = xcue[0][i + 1] - xleft;
		dright = xcue[1][j] - xright;

		// compute stuff
		if (dleft < dright)
			dmin = dleft;
		else
			dmin = dright;

		// must find the min-max value of the functions fidxue[0][i] and fidxue[1][j - 1] defined on the intervals [xleft, xleft+dmin] and [xright, xright+dmin]

		f = fidxue[0][i]; // f1(xx) = w[f] * (xx - x[f]) ==> increasing, as xx increases
		g = fidxue[1][j - 1]; // f2(xx) = w[g] * (x[g] - xx) ==> decreasing, as xx decreases

		if ((w[f] * (xleft - x[f])) > (w[g] * (x[g] - xright)))
		{
			local_dwmin = w[f] * (xleft - x[f]);
			local_xpos = xleft;
			local_dwmin_type = 0;
		}
		else
		if ((w[f] * (xleft + dmin - x[f])) < (w[g] * (x[g] - xright - dmin)))
		{
			local_dwmin = w[g] * (x[g] - xright - dmin);
			local_xpos = xleft + dmin;
			local_dwmin_type = 1;
		}
		else
		{
			xcross = ((double) (w[g] * (x[g] - xright)) - (double) (w[f] * (xleft - x[f]))) / (double) (w[f] + w[g]);
			local_xpos = xleft + xcross;
			local_dwmin = w[f] * (local_xpos - x[f]);
			local_dwmin_type = 2;
		}

		//fprintf(stderr, "[%.3lf-%.3lf]--[%.3lf-%.3lf] => f=%d, g=%d, local_dwmin=%.3lf (local_xpos=%.3lf, local_type=%d)\n", xleft, xleft + dmin, xright, xright + dmin, f, g, local_dwmin, local_xpos, local_dwmin_type);

		if (local_dwmin < dwmin)
		{
			dwmin = local_dwmin;
			dwmin_type = local_dwmin_type;
			xpos = local_xpos;
			fsol = f;
			gsol = g;

			//fprintf(stderr, "[%.3lf-%.3lf]--[%.3lf-%.3lf] => f=%d, g=%d, local_dwmin=%.3lf (local_xpos=%.3lf, local_type=%d)\n", xleft, xleft + dmin, xright, xright + dmin, f, g, local_dwmin, local_xpos, local_dwmin_type);
		}

		// move to the next event
		if (dleft < dright)
		{
			i++;
			xleft = xcue[0][i];
		}
		else
			xleft += dright;

		xright = xleft + L;
	}


	fprintf(stderr, "min-max weighted distance=%.3lf [%.3lf-%.3lf] (type=%d, fsol=%d, gsol=%d)\n", dwmin, xpos, xpos + L, dwmin_type, fsol, gsol);
}

#define minim(a,b) ((a) < (b) ? (a) : (b))
#define maxim(a,b) ((a) > (b) ? (a) : (b))

int main()
{
	freopen("center.in", "r", stdin);

	scanf("%d %d %lld %lld %lld %lld %lld", &N, &L, &w[1], &A, &B, &C, &D);
	x[1] = 0;

	for (i = 2; i <= N; i++)
	{ // good rule ?
		x[i] = x[i - 1] + 1 + (((x[i - 1] * i) ^ A) % B);
		//w[i] = 1 + ((((w[i - 1] * B) ^ (long long) (i * D)) % minim(i, N - i + 1)));
		if (2 * i <= N)
			k = 1;
		else
			k = -1;

		w[i] = maxim(1, w[i - 1] + k * (1 + ((w[i - 1] * (i + C)) ^ (D * i)) % D));
		C = 1 + ((((C * C) % D) * i) % D);
	}

	/*
	N = 3;
	x[1] = 0; w[1] = 2;
	x[2] = 33; w[2] = 7;
	x[3] = 60; w[3] = 2;
	*/

	fprintf(stderr, "N=%d\n", N);
	for (i = N; i <= N; i++)
		fprintf(stderr, "%d: %lld %lld\n", i, x[i], w[i]);
	
	
	if (x[N] - x[1] <= L)
	{
		printf("0\n%lld\n", x[1]);
		return 0;
	}

	// upper envelope of a set of linear functions -- left to right
	upper_envelope_LtoR();

	// upper envelope of a set of linear functions -- left to right
	upper_envelope_RtoL();

	center_traversal();

	freopen("center.out", "w", stdout);
	printf("%.3lf\n%.8lf\n", dwmin, xpos);

	return 0;
}
