/*
 * Problem: Find out the number of simple undirected graphs having N vertices with the property that in each 
 *          connected component the number of vertices is equal to the number of edges. In addition, every
 *          cycle's length must be at least K.
 * Author: Andrei Grigorean
 * Date: 13.06.2008
 * Time complexity: O(N^3)
 * Memory complexity: O(N^2)
 * Expected score: 100/100
*/

#include <fstream>
using namespace std;

const char FILEIN[] = "shgraf.in";		// Input file
const char FILEOUT[] = "shgraf.out";	// Output file
const int MAXN = 256;					// Maximum value of N
const int MOD = 30011;					// The result must be printed modulo MOD

int N, K;					// Input data
int Comb[MAXN][MAXN];		// Comb[i][j] = number of ways of choosing j objects out of a total of i
int Pruffer[MAXN];			// Pruffer[i] = (i+1) ^ (i-1) = number of trees having i+1 vertices
int A[MAXN][MAXN];			// A[i][j] = number of ways of choosing the j nodes that aren't on the cycle if the cycle's length is i
int B[MAXN];				// B[i] = number of cycles with i vertices
int C[MAXN];				// C[i] = number of connected graphs having i vertices
int D[MAXN];				// D[i] = number of graphs with i vertices

void ReadData() {
	ifstream fin(FILEIN);
	fin >> N >> K;
}

void GenerateComb() {
	for (int i = 0; i <= N; ++i) {
		Comb[i][0] = 1;
		for (int j = 1; j <= i; ++j)
			Comb[i][j] = (Comb[i-1][j-1] + Comb[i-1][j]) % MOD;
	}
}

void BuildPruffer() {
	for (int i = 0; i <= N; ++i) {
		Pruffer[i] = 1;
		for (int j = 1; j < i; ++j)
			Pruffer[i] = (Pruffer[i] * (i+1)) % MOD;
	}
}

void BuildA() {
	A[0][0] = 1;
	for (int i = 1; i <= N; ++i)
		for (int j = 0; j <= N; ++j)
			for (int k = 0; j + k <= N; ++k)
				A[i][j+k] = (A[i][j+k] + ((A[i-1][j] * Pruffer[k]) % MOD) * Comb[j+k][k]) % MOD;
}

void BuildB() {
	B[3] = 1;
	for (int i = 4; i <= N; ++i)
		B[i] = (B[i-1] * (i-1)) % MOD;
}

void BuildC() {
	C[0] = 1;
	for (int i = K; i <= N; ++i)
		for (int j = 0; i+j <= N; ++j)
			C[i+j] = (C[i+j] + ((A[i][j] * B[i]) % MOD) * Comb[i+j][i]) % MOD;
}

void BuildD() {
	D[0] = 1;

	for (int i = 3; i <= N; ++i)
		for (int j = 3; j <= i; ++j)
			D[i] = (D[i] + ((D[i-j] * C[j]) % MOD) * Comb[i-1][j-1]) % MOD;
}

void Solve() {
	GenerateComb();
	BuildPruffer();
	BuildA();
	BuildB();
	BuildC();
	BuildD();
}

void WriteData() {
	ofstream fout(FILEOUT);
	fout << D[N]<<'\n';
}

int main() {
	ReadData();
	Solve();
	WriteData();
}
